@@ -30,15 +30,19 @@ Subpackages
    fgui
    fsread
    functions
+   jams
    kernel_regression
+   lhs
    mad
    mcplot
    means
    morris_method
+   ncinfo
    ncio
+   ncread
    npyio
+   pack
    position
-   readnetcdf
    romanliterals
    sce
    screening
@@ -47,42 +51,54 @@ Subpackages
    text2plot
 
 History
-    * Written Oct 2021 by Matthias Cuntz (mc (at) macu (dot) de)
-    * v1.0, initial Github, PyPI, Zenodo commit, Oct 2021, Matthias Cuntz
-    * v1.1, automatic versioning, zenodo defaults, Oct 2021, Matthias Cuntz
-    * v1.2, added closest, Oct 2021, Matthias Cuntz
-    * v1.3, added argsort, Oct 2021, Matthias Cuntz
-    * v1.4, added division, Oct 2021, Matthias Cuntz
-    * v1.5, added alpha_equ_h2o, Oct 2021, Matthias Cuntz
-    * v1.6, added alpha_kin_h2o, Nov 2021, Matthias Cuntz
-    * v1.7, added mcPlot, Nov 2021, Matthias Cuntz
-    * v1.8, added str2tex and color, Nov 2021, Matthias Cuntz
-    * v1.9, added position, Nov 2021, Matthias Cuntz
-    * v1.10, added sron colors, Nov 2021, Matthias Cuntz
-    * v1.11, added text2plot, abc2plot, signature2plot,
-      Nov 2021, Matthias Cuntz
-    * v1.12, added date2dec and all its wrappers, Dec 2021, Matthias Cuntz
-    * v1.13, added fsread, fread, sread, Dec 2021, Matthias Cuntz
-    * v1.14, added GUI dialogs to choose files and directories using Tkinter,
-      Jan 2022, Matthias Cuntz
-    * v1.15, added esat, Jan 2022, Matthias Cuntz
-    * v1.16, added mad, Jan 2022, Matthias Cuntz
-    * v1.17, added xread, xlsread, and xlsxread, Jan 2022, Matthias Cuntz
-    * v1.18, helper module to preserve input types, Mar 2022, Matthias Cuntz
-    * v1.19, added readnetcdf, Mar 2022, Matthias Cuntz
-    * v1.20, added gridcellarea and kernel_regression, Apr 2022, Matthias Cuntz
-    * v1.21, enhancements in color and kernel_regression,
-      Apr 2022, Matthias Cuntz
-    * v1.22, added ncio, May 2022, Matthias Cuntz
-    * v1.23, added datetime module, Jun 2022, Matthias Cuntz
-    * v1.24, moved docu to Github Pages, Jun 2022, Matthias Cuntz
-    * v1.25, Microseconds and negative years in date2date and datetime,
-      Jun 2022, Matthias Cuntz
-    * v1.26, added means, Jul 2022, Matthias Cuntz
-    * v1.27, added sce, Dec 2022, Matthias Cuntz
-    * v1.28, added updatez, Jan 2023, Matthias Cuntz
-    * v1.29, added functions for converting humidity in air,
-      Jan 2023, Matthias Cuntz
+   * Written Oct 2021 by Matthias Cuntz (mc (at) macu (dot) de)
+   * v1.0, initial Github, PyPI, Zenodo commit, Oct 2021, Matthias Cuntz
+   * v1.1, automatic versioning, zenodo defaults, Oct 2021, Matthias Cuntz
+   * v1.2, added closest, Oct 2021, Matthias Cuntz
+   * v1.3, added argsort, Oct 2021, Matthias Cuntz
+   * v1.4, added division, Oct 2021, Matthias Cuntz
+   * v1.5, added alpha_equ_h2o, Oct 2021, Matthias Cuntz
+   * v1.6, added alpha_kin_h2o, Nov 2021, Matthias Cuntz
+   * v1.7, added mcPlot, Nov 2021, Matthias Cuntz
+   * v1.8, added str2tex and color, Nov 2021, Matthias Cuntz
+   * v1.9, added position, Nov 2021, Matthias Cuntz
+   * v1.10, added sron colors, Nov 2021, Matthias Cuntz
+   * v1.11, added text2plot, abc2plot, signature2plot,
+     Nov 2021, Matthias Cuntz
+   * v1.12, added date2dec and all its wrappers, Dec 2021, Matthias Cuntz
+   * v1.13, added fsread, fread, sread, Dec 2021, Matthias Cuntz
+   * v1.14, added GUI dialogs to choose files and directories using Tkinter,
+     Jan 2022, Matthias Cuntz
+   * v1.15, added esat, Jan 2022, Matthias Cuntz
+   * v1.16, added mad, Jan 2022, Matthias Cuntz
+   * v1.17, added xread, xlsread, and xlsxread, Jan 2022, Matthias Cuntz
+   * v1.18, helper module to preserve input types, Mar 2022, Matthias Cuntz
+   * v1.19, added readnetcdf, Mar 2022, Matthias Cuntz
+   * v1.20, added gridcellarea and kernel_regression, Apr 2022, Matthias Cuntz
+   * v1.21, enhancements in color and kernel_regression,
+     Apr 2022, Matthias Cuntz
+   * v1.22, added ncio, May 2022, Matthias Cuntz
+   * v1.23, added datetime module, Jun 2022, Matthias Cuntz
+   * v1.24, moved docu to Github Pages, Jun 2022, Matthias Cuntz
+   * v1.25, Microseconds and negative years in date2date and datetime,
+     Jun 2022, Matthias Cuntz
+   * v1.26, added means, Jul 2022, Matthias Cuntz
+   * v1.27, added sce, Dec 2022, Matthias Cuntz
+   * v1.28, added updatez, Jan 2023, Matthias Cuntz
+   * v1.29, added functions for converting humidity in air,
+     Jan 2023, Matthias Cuntz
+   * v1.30, hvplot in mcplot, May 2023, Matthias Cuntz
+   * v1.31, added pack and unpack, Jun 2023, Matthias Cuntz
+   * v1.32, added jams, Jun 2023, Matthias Cuntz
+   * v1.33, start supporting pandas Series and DataFrames,
+     Jul 2023, Matthias Cuntz
+   * v2.0, full pandas support, Sep 2023, Matthias Cuntz
+   * v2.1, ncread and ncinfo in individual files, Nov 2023, Matthias Cuntz
+   * v2.2, enhancements of plotting routines, ncio, fsread, and datetime,
+     Aug 2024, Matthias Cuntz
+   * v2.3, deprecate ncio and plotting routines that became standalone
+     packages, Oct 2024, Matthias Cuntz
+   * v2.4, added lhs, Oct 2025, Matthias Cuntz
 
 """
 # version, author
@@ -103,6 +119,8 @@ from . import functions
 # netCDF4 functions to copy netcdf file while doing some transformations on
 # variables and dimensions.
 from . import ncio
+# old JAMS routines
+from . import jams
 
 # air humidity calculations
 from .air_humidity import esat, eair2rhair, rhair2eair
@@ -129,13 +147,18 @@ from .division import division, div
 # cftime extension
 from .class_datetime import date2dec, date2num, dec2date, num2date, datetime
 # GUI dialogs to choose files and directories using Tkinter
-from .fgui import directory_from_gui, directories_from_gui
-from .fgui import file_from_gui, files_from_gui
+try:  # Tkinter must be installed
+    from .fgui import directory_from_gui, directories_from_gui
+    from .fgui import file_from_gui, files_from_gui
+except ImportError:
+    pass
 # read numbers and strings from a file into 2D float and string arrays
 from .fsread import fsread, fread, sread
 from .fsread import xread, xlsread, xlsxread
 # multi-dimensional non-parametric kernel regression
 from .kernel_regression import kernel_regression_h, kernel_regression
+# latin hypercube sampling
+from .lhs import lhs
 # median absolute deviation test
 from .mad import mad
 # Matthias Cuntz' standard plotting class.
@@ -146,12 +169,16 @@ from .means import means
 # Sampling of optimised trajectories for and calculation of Morris Measures /
 # Elementary Effects
 from .morris_method import morris_sampling, elementary_effects
+# print information of a netcdf file
+from .ncinfo import ncinfo, infonetcdf
+# get variables from a netcdf file
+from .ncread import ncread, readnetcdf
 # update arrays in a single file in numpy's npz format
 from .npyio import updatez, updatez_compressed
+# like Fortran pack/unpack
+from .pack import pack, unpack
 # positions of subplots, used with add_axes
 from .position import position
-# get variables from or print information of a netcdf file
-from .readnetcdf import infonetcdf, ncinfo, readnetcdf, ncread
 # Convert integer to and from Roman numerals
 from .romanliterals import int2roman, roman2int
 # Shuffled-Complex-Evolution (SCE) algorithm for function minimization
@@ -189,14 +216,17 @@ __all__ = ['__version__', '__author__',
            'file_from_gui', 'files_from_gui',
            'fsread', 'fread', 'sread',
            'xread', 'xlsread', 'xlsxread',
-           'kernel_regression_h', 'kernel_regression'
+           'kernel_regression_h', 'kernel_regression',
+           'lhs',
            'mad',
            'mcPlot',
            'means',
            'morris_sampling', 'elementary_effects',
+           'ncinfo', 'infonetcdf',
+           'ncread', 'readnetcdf',
            'updatez', 'updatez_compressed',
+           'pack', 'unpack',
            'position',
-           'infonetcdf', 'ncinfo', 'readnetcdf', 'ncread',
            'int2roman', 'roman2int',
            'sce',
            'screening', 'ee',
