@@ -26,9 +26,11 @@ History
     * Using numpy docstring format, extending examples from numpy docstrings,
       May 2020, Matthias Cuntz
     * More consistent docstrings, Jan 2022, Matthias Cuntz
+    * Support pandas.Series, Jun 2023, Matthias Cuntz
 
 """
 import numpy as np
+import pandas as pd
 
 
 __all__ = ['argmax', 'argmin', 'argsort']
@@ -36,8 +38,7 @@ __all__ = ['argmax', 'argmin', 'argsort']
 
 def argmax(a, *args, **kwargs):
     """
-    Wrapper for numpy.argmax, numpy.ma.argmax, and using max for Python
-    iterables.
+    Wrapper for numpy.argmax, numpy.ma.argmax, and max for Python iterables
 
     Passes all keywords directly to the individual routines, i.e.
 
@@ -134,14 +135,15 @@ def argmax(a, *args, **kwargs):
         return np.ma.argmax(a, *args, **kwargs)
     elif isinstance(a, np.ndarray):
         return np.argmax(a, *args, **kwargs)
+    elif isinstance(a, pd.Series):
+        return a.argmax(*args, **kwargs)
     else:
         return _argmax(a)
 
 
 def argmin(a, *args, **kwargs):
     """
-    Wrapper for numpy.argmin, numpy.ma.argmin, and using min for Python
-    iterables
+    Wrapper for numpy.argmin, numpy.ma.argmin, and min for Python iterables
 
     Passes all keywords directly to the individual routines, i.e.
 
@@ -238,13 +240,15 @@ def argmin(a, *args, **kwargs):
         return np.ma.argmin(a, *args, **kwargs)
     elif isinstance(a, np.ndarray):
         return np.argmin(a, *args, **kwargs)
+    elif isinstance(a, pd.Series):
+        return a.argmin(*args, **kwargs)
     else:
         return _argmin(a)
 
 
 def argsort(a, *args, **kwargs):
     """
-    Wrapper for numpy.argsort, numpy.ma.argsort, and using sorted for Python
+    Wrapper for numpy.argsort, numpy.ma.argsort, and sorted for Python
     iterables
 
     Passes all keywords directly to the individual routines, i.e.
@@ -371,6 +375,8 @@ def argsort(a, *args, **kwargs):
         return np.ma.argsort(a, *args, **kwargs)
     elif isinstance(a, np.ndarray):
         return np.argsort(a, *args, **kwargs)
+    elif isinstance(a, pd.Series):
+        return a.argsort(*args, **kwargs)
     else:
         return _argsort(a, *args, **kwargs)
 
