@@ -77,6 +77,10 @@ History
     * round_microseconds method for datetime, Jul 2022, Matthias Cuntz
     * only_use_pyjams_datetimes keyword in num2date, Jan 2022, Matthias Cuntz
     * Also CF-calendars in datetime class, Jan 2023, Matthias Cuntz
+    * Use longdouble keyword with date2num if cftime > v1.6.1,
+      Aug 2024, Matthias Cuntz
+    * Filter UserWarning from cftime, Aug 2024, Matthias Cuntz
+    * ensure_seconds keyword in date2num, Aug 2024, Matthias Cuntz
 
 ToDo
     * Check why datetime + timedelta but not timedelta + datetime
@@ -84,12 +88,14 @@ ToDo
     * add time2index
     * implement fromordinal
     * implement change_calendar
+    * strptime
 
 """
-import re
-import time as ptime
 from datetime import datetime as datetime_python
 from datetime import timedelta
+import re
+import time as ptime
+import warnings
 import numpy as np
 import cftime as cf
 from .helper import input2array, array2input
@@ -97,9 +103,7 @@ from .date2date import date2date
 # from pyjams.helper import input2array, array2input
 # from pyjams.date2date import date2date
 
-
-# from ._cftime import num2date, date2num, date2index, time2index, num2pydate
-__all__ = ['date2dec', 'date2num', 'date2dec', 'num2date', 'datetime']
+__all__ = ['date2dec', 'date2num', 'dec2date', 'num2date', 'datetime']
 
 
 # supported calendars. Includes synonyms ('excel'=='excel1900')
@@ -122,6 +126,8 @@ _cumdayspermonth_leap = [0, 31, 60, 91, 121, 152, 182,
                          213, 244, 274, 305, 335, 366]
 _cumdayspermonth_360  = [0, 30, 60, 90, 120, 150, 180,
                          210, 240, 270, 300, 330, 360]
+# feps = np.finfo(np.float64).eps
+deps = np.finfo(np.longdouble).eps
 
 #
 # Exact copies of private cftime routines
@@ -1094,7 +1100,8 @@ def _absolute2date(times, units):
 #
 
 def date2num(dates, units='', calendar=None, has_year_zero=None,
-             format='', timesep=' ', fr=False, return_arrays=False):
+             format='', timesep=' ', fr=False, return_arrays=False,
+             ensure_seconds=False):
     """
     Return numeric time values given datetime objects or strings
 
@@ -1175,6 +1182,21 @@ def date2num(dates, units='', calendar=None, has_year_zero=None,
     return_arrays : bool, optional
         If True, then return a tuple with individual arrays for
         year, month, day, hour, minute, second, microsecond
+    ensure_seconds : bool, optional
+        If True, add small number (< 20 microseconds) to results to
+        ensure that back-conversion (`num2date`) gives the same results
+        up to seconds.
+
+        Results should have an accuracy of approximately 1 microseconds.
+        This is however only possible with 64-bits if the discretization
+        of the time variable is an integer multiple of the units.
+        `cftime` introduced the longdouble keyword in `cftime.date2num`
+        to get microseconds accuracy. The datatype is, however, not available
+        on all platforms. The algorithm has the tendency to give
+        1-3 microseconds less at back-conversion in this case, which gives
+        times such as '11:59:59' instead of '12:00:00'. `ensure_seconds`
+        toggles back-conversion above the next second to ensure that the
+        seconds are correct.
 
     Returns
     -------
@@ -1286,8 +1308,13 @@ def date2num(dates, units='', calendar=None, has_year_zero=None,
             if int(remainder.split('-')[0]) == 0:
                 if has_year_zero is not None:
                     has_year_zero = True
-        out = cf.date2num(mdates, units, calendar=icalendar,
-                          has_year_zero=has_year_zero)
+        if cf.__version__ > '1.6.1':
+            out = cf.date2num(mdates, units, calendar=icalendar,
+                              has_year_zero=has_year_zero,
+                              longdouble=True)
+        else:
+            out = cf.date2num(mdates, units, calendar=icalendar,
+                              has_year_zero=has_year_zero)
 
     if sincestr == 'as':
         if units not in ['day as %Y%m%d.%f', 'month as %Y%m.%f',
@@ -1300,13 +1327,22 @@ def date2num(dates, units='', calendar=None, has_year_zero=None,
         cfcalendar = 'julian'
         cfdates = [ cf.datetime(*to_tuple(dt), calendar=cfcalendar)
                     for dt in mdates ]
-        out = cf.date2num(cfdates, units, calendar=cfcalendar,
-                          has_year_zero=has_year_zero)
+        if cf.__version__ > '1.6.1':
+            out = cf.date2num(cfdates, units, calendar=cfcalendar,
+                              has_year_zero=has_year_zero,
+                              longdouble=True)
+        else:
+            out = cf.date2num(cfdates, units, calendar=cfcalendar,
+                              has_year_zero=has_year_zero)
 
     # no cftime.num2date possible
     if icalendar in _decimalcalendars:
         out = _dates2decimal(mdates, icalendar)
 
+    # toggle back-conversion above the second
+    if ensure_seconds:
+        out += np.abs(out) * deps
+
     out = array2input(out, dates)
     return out
 
@@ -1314,6 +1350,7 @@ def date2num(dates, units='', calendar=None, has_year_zero=None,
 def date2dec(*args, **kwargs):
     """
     Wrapper for :func:`date2num`
+
     """
     return date2num(*args, **kwargs)
 
@@ -1638,6 +1675,7 @@ def num2date(times, units='', calendar='standard',
 def dec2date(*args, **kwargs):
     """
     Wrapper for :func:`num2date`
+
     """
     return num2date(*args, **kwargs)
 
@@ -1659,7 +1697,7 @@ class datetime(object):
     calendars are supposedly Julian calendars with other reference dates.
     Day 0 of *excel*/*excel1900* starts at 1899-12-31 00:00:00 and day 0
     of *excel1904* (old Lotus date) starts at 1903-12-31 00:00:00.
-    Decimal calendars have the form "%Y.%f", where the fractional year
+    Decimal calendars have the form '%Y.%f', where the fractional year
     assumes leap years as the proleptic Gregorian calendar, or fixed 360,
     365, or 366 days per year.
 
@@ -1740,7 +1778,7 @@ class datetime(object):
         # year
         if not self.has_year_zero:
             if self.year == 0:
-                raise ValueError("Invalid year provided in {0!r}".format(self))
+                raise ValueError('Invalid year provided in {0!r}'.format(self))
         # Comment next block to allow negative days with Excel calendars,
         # which does not exist in Excel
         # if ( ((self.calendar == 'excel') or (self.calendar == 'excel1900'))
@@ -1751,31 +1789,31 @@ class datetime(object):
 
         # month
         if (self.month < 1) or (self.month > 12):
-            raise ValueError("Invalid month provided in {0!r}".format(self))
+            raise ValueError('Invalid month provided in {0!r}'.format(self))
 
         # day
         month_length = _month_lengths(self.year, self.calendar,
                                       self.has_year_zero)
         if (self.day < 1) or (self.day > month_length[self.month - 1]):
             raise ValueError(
-                "Invalid day number provided in {0!r}".format(self))
+                'Invalid day number provided in {0!r}'.format(self))
 
         # hour
         if (self.hour < 0) or (self.hour > 23):
-            raise ValueError("Invalid hour provided in {0!r}".format(self))
+            raise ValueError('Invalid hour provided in {0!r}'.format(self))
 
         # minute
         if (self.minute < 0) or (self.minute > 59):
-            raise ValueError("Invalid minute provided in {0!r}".format(self))
+            raise ValueError('Invalid minute provided in {0!r}'.format(self))
 
         # second
         if (self.second < 0) or (self.second > 59):
-            raise ValueError("Invalid second provided in {0!r}".format(self))
+            raise ValueError('Invalid second provided in {0!r}'.format(self))
 
         # microsecond
         if (self.microsecond) < 0 or (self.microsecond > 999999):
             raise ValueError(
-                "Invalid microsecond provided in {0!r}".format(self))
+                'Invalid microsecond provided in {0!r}'.format(self))
 
     def change_calendar(self, calendar, has_year_zero=None):
         return NotImplemented
@@ -1899,15 +1937,15 @@ class datetime(object):
         Identical to cftime.datetime
 
         """
-        args = {"year": self.year,
-                "month": self.month,
-                "day": self.day,
-                "hour": self.hour,
-                "minute": self.minute,
-                "second": self.second,
-                "microsecond": self.microsecond,
-                "has_year_zero": self.has_year_zero,
-                "calendar": self.calendar}
+        args = {'year': self.year,
+                'month': self.month,
+                'day': self.day,
+                'hour': self.hour,
+                'minute': self.minute,
+                'second': self.second,
+                'microsecond': self.microsecond,
+                'has_year_zero': self.has_year_zero,
+                'calendar': self.calendar}
 
         if 'dayofyr' in kwargs or 'dayofwk' in kwargs:
             raise ValueError('Replacing the dayofyr or dayofwk of a datetime'
@@ -2075,8 +2113,10 @@ class datetime(object):
         # has_year_zero = self.has_year_zero
         # delta = other
         if calendar == 'decimal360':
-            cfdt = cf.datetime(*to_tuple(dt), calendar='360_day',
-                               has_year_zero=dt.has_year_zero)
+            with warnings.catch_warnings():
+                warnings.simplefilter('ignore')
+                cfdt = cf.datetime(*to_tuple(dt), calendar='360_day',
+                                   has_year_zero=dt.has_year_zero)
             cfdt = cfdt + delta
             year, month, day, hour, minute, second, microsecond = (
                 cfdt.year, cfdt.month, cfdt.day, cfdt.hour, cfdt.minute,
@@ -2123,7 +2163,7 @@ class datetime(object):
         Identical to cftime.datetime
 
         """
-        # the string format "{t_obj}".format(t_obj=t_obj)
+        # the string format '{t_obj}'.format(t_obj=t_obj)
         # without an explicit format gives an empty string (format='')
         # so set this to None to get the default strftime behaviour
         if not format:
@@ -2157,8 +2197,8 @@ class datetime(object):
         String representation
 
         """
-        return ("{0}.{1}({2}, {3}, {4}, {5}, {6}, {7}, {8},"
-                " calendar={9}, has_year_zero={10})".format(
+        return ('{0}.{1}({2}, {3}, {4}, {5}, {6}, {7}, {8},'
+                ' calendar={9}, has_year_zero={10})'.format(
                     'pyjams',
                     self.__class__.__name__,
                     self.year, self.month, self.day,
@@ -2184,16 +2224,16 @@ class datetime(object):
             if isinstance(other, datetime):
                 # datetime - datetime
                 if dt.calendar != other.calendar:
-                    raise TypeError("Cannot compute the time difference"
-                                    " between dates with different calendars")
-                if dt.calendar == "":
-                    raise TypeError("Cannot compute the time difference"
-                                    " between dates that are not"
-                                    " calendar-aware")
+                    raise TypeError('Cannot compute the time difference'
+                                    ' between dates with different calendars')
+                if dt.calendar == '':
+                    raise TypeError('Cannot compute the time difference'
+                                    ' between dates that are not'
+                                    ' calendar-aware')
                 if dt.has_year_zero != other.has_year_zero:
-                    raise TypeError("Cannot compute the time difference"
-                                    " between dates with different year zero"
-                                    " conventions")
+                    raise TypeError('Cannot compute the time difference'
+                                    ' between dates with different year zero'
+                                    ' conventions')
                 ord1 = 0
                 if self.calendar == 'decimal':
                     ord1 = 1721425
@@ -2224,8 +2264,10 @@ class datetime(object):
             elif isinstance(other, timedelta):
                 # datetime - timedelta
                 if dt.calendar == 'decimal360':
-                    cfdt = cf.datetime(*to_tuple(dt), calendar='360_day',
-                                       has_year_zero=dt.has_year_zero)
+                    with warnings.catch_warnings():
+                        warnings.simplefilter("ignore")
+                        cfdt = cf.datetime(*to_tuple(dt), calendar='360_day',
+                                           has_year_zero=dt.has_year_zero)
                     cfdt = cfdt - other
                     year, month, day, hour, minute, second, microsecond = (
                         cfdt.year, cfdt.month, cfdt.day, cfdt.hour,
