@@ -6,7 +6,7 @@ This module was written by Matthias Cuntz while at Institut National de
 Recherche pour l'Agriculture, l'Alimentation et l'Environnement (INRAE), Nancy,
 France.
 
-:copyright: Copyright 2021-2022 Matthias Cuntz, see AUTHORS.rst for details.
+:copyright: Copyright 2021- Matthias Cuntz, see AUTHORS.rst for details.
 :license: MIT License, see LICENSE for details.
 
 .. moduleauthor:: Matthias Cuntz
@@ -35,8 +35,13 @@ History
       matplotlib.colormaps.get_cmap(name) to work with matplotlib < v3.6,
       Jan 2023, Matthias Cuntz
     * Do not set_bad() for sron palettes, Jan 2023, Matthias Cuntz
+    * Allow ncol=1 in get_cmap, Jun 2023, Matthias Cuntz
+    * Added IPCC colours, Feb 2024, Matthias Cuntz
 
 """
+from warnings import warn, filterwarnings
+filterwarnings("default", category=DeprecationWarning)
+
 
 __all__ = ['get_color', 'print_colors',
            'get_cmap', 'print_palettes', 'show_palettes']
@@ -114,6 +119,10 @@ def get_color(cname=''):
     from collections.abc import Iterable
     import matplotlib.pyplot as plt
     import pyjams.color
+    warn('The plotting functions of pyjams were transferred to a'
+         ' standalone repository "mcplot". get_color is hence deprecated'
+         ' in pyjams.',
+         category=DeprecationWarning)
 
     mapping = plt.cm.colors.get_named_colors_mapping
     # register ufz colors if not yet done
@@ -158,6 +167,10 @@ def print_colors(collection=''):
     """
     import matplotlib.pyplot as plt
     import pyjams.color
+    warn('The plotting functions of pyjams were transferred to a'
+         ' standalone repository "mcplot". print_color is hence deprecated'
+         ' in pyjams.',
+         category=DeprecationWarning)
 
     if collection:
         if isinstance(collection, str):
@@ -262,6 +275,10 @@ def get_cmap(palette, ncol=0, offset=0, upper=1,
     import matplotlib.pyplot as plt
     import pyjams.color
     from pyjams import argsort
+    warn('The plotting functions of pyjams were transferred to a'
+         ' standalone repository "mcplot". get_cmap is hence deprecated'
+         ' in pyjams.',
+         category=DeprecationWarning)
 
     # _r at end of palette is same as reverse=True
     if palette.endswith('_r'):
@@ -283,6 +300,9 @@ def get_cmap(palette, ncol=0, offset=0, upper=1,
     oregon_collections = [ i for i in dir(pyjams.color)
                            if i.startswith('oregon_')
                            and not i.endswith('_palettes') ]
+    ipcc_collections = [ i for i in dir(pyjams.color)
+                         if i.startswith('ipcc_')
+                         and not i.endswith('_palettes') ]
     ncl_collections = [ i for i in dir(pyjams.color)
                         if i.startswith('ncl_')
                         and not i.endswith('_palettes') ]
@@ -340,7 +360,11 @@ def get_cmap(palette, ncol=0, offset=0, upper=1,
                     else:
                         ncol1 = ncol
                     for i in range(ncol1):
-                        x = offset + float(i)/float(ncol1-1) * (upper-offset)
+                        if ncol1 == 1:
+                            x = offset
+                        else:
+                            x = (offset + float(i) / float(ncol1 - 1) *
+                                 (upper - offset))
                         colors.append(tuple(dd[palette](x)))
 
     if not found_palette:
@@ -357,6 +381,13 @@ def get_cmap(palette, ncol=0, offset=0, upper=1,
                 found_palette = True
                 colors = [ _rgb2rgb(i) for i in dd[palette] ]
 
+    if not found_palette:
+        for bb in ipcc_collections:
+            dd = eval('pyjams.color.' + bb)
+            if palette in dd:
+                found_palette = True
+                colors = [ _rgb2rgb(i) for i in dd[palette] ]
+
     if not found_palette:
         for bb in ncl_collections:
             dd = eval('pyjams.color.' + bb)
@@ -406,7 +437,7 @@ def get_cmap(palette, ncol=0, offset=0, upper=1,
                 colors = [ _rgb2rgb(i) for i in dd[palette] ]
 
     if not found_palette:
-        raise ValueError(palette+' color palette not found.')
+        raise ValueError(palette + ' color palette not found.')
 
     if order is not None:
         hsv = ['hue', 'saturation', 'value']
@@ -427,10 +458,14 @@ def get_cmap(palette, ncol=0, offset=0, upper=1,
     # subsample
     if (ncol > 0) and not nosubsample:
         ncolors = len(colors)
-        ocolors = ['']*ncol
+        ocolors = [''] * ncol
         for i in range(ncol):
-            x = offset + float(i)/float(ncol-1) * (upper-offset)  # [0-1]
-            iicol = round(x * (ncolors-1))  # [0-ncolor-1]
+            if ncol == 1:
+                x = offset
+            else:
+                # [0-1]
+                x = offset + float(i) / float(ncol - 1) * (upper - offset)
+            iicol = round(x * (ncolors - 1))  # [0-ncolor-1]
             ocolors[i] = colors[iicol]
         colors = ocolors
 
@@ -452,7 +487,7 @@ def print_palettes(collection=''):
     collection : str or list of strings, optional
         Name(s) of color palette collection(s).
         Known collections are 'pyjams', 'sron', 'sron2012', 'mathematica',
-        'oregon', 'ncl', 'matplotlib', and 'brewer'.
+        'oregon', 'ipcc', 'ncl', 'matplotlib', and 'brewer'.
 
     Returns
     -------
@@ -467,9 +502,13 @@ def print_palettes(collection=''):
        print_palettes()
 
     """
-    import matplotlib as mpl
+    # import matplotlib as mpl
     import matplotlib.pyplot as plt
     import pyjams.color
+    warn('The plotting functions of pyjams were transferred to a'
+         ' standalone repository "mcplot". print_palettes is hence deprecated'
+         ' in pyjams.',
+         category=DeprecationWarning)
 
     pyjams_collections = [ i for i in dir(pyjams.color)
                            if i.startswith('pyjams_')
@@ -486,6 +525,9 @@ def print_palettes(collection=''):
     oregon_collections = [ i for i in dir(pyjams.color)
                            if i.startswith('oregon_')
                            and not i.endswith('_palettes') ]
+    ipcc_collections = [ i for i in dir(pyjams.color)
+                         if i.startswith('ipcc_')
+                         and not i.endswith('_palettes') ]
     ncl_collections = [ i for i in dir(pyjams.color)
                         if i.startswith('ncl_')
                         and not i.endswith('_palettes') ]
@@ -499,8 +541,8 @@ def print_palettes(collection=''):
         else:
             collections = [ i.lower for i in collection ]
     else:
-        collections = ['pyjams', 'sron', 'sron2012', 'mathematica',
-                       'oregon', 'ncl', 'matplotlib', 'brewer']
+        collections = ['pyjams', 'sron', 'sron2012', 'mathematica', 'oregon',
+                       'ipcc', 'ncl', 'matplotlib', 'brewer']
 
     if 'pyjams' in collections:
         print('pyjams')
@@ -537,6 +579,13 @@ def print_palettes(collection=''):
             ll = eval('pyjams.color.' + cc + '.keys()')
             print('       ', list(ll))
 
+    if 'ipcc' in collections:
+        print('ipcc')
+        for cc in ipcc_collections:
+            print('   ', cc)
+            ll = eval('pyjams.color.' + cc + '.keys()')
+            print('       ', list(ll))
+
     if 'ncl' in collections:
         print('ncl')
         for cc in ncl_collections:
@@ -595,7 +644,7 @@ def _newsubplot(nrow, ncol, iplot, iname, ncolors=0):  # pragma: no cover
         iiname = iname + '(' + str(ncolors) + ')'
     else:
         iiname = iname
-    ax.text(xmin+dx*(xmax-xmin), ymin+dy*(ymax-ymin), iiname,
+    ax.text(xmin + dx * (xmax - xmin), ymin + dy * (ymax - ymin), iiname,
             ha='right', va='center')
     # return ax
 
@@ -627,7 +676,7 @@ def show_palettes(outfile='', collection=''):  # pragma: no cover
         Name(s) of color palette collection(s).
         All palettes will be shown if collection is empty or 'all'.
         Known collections are: 'pyjams', 'sron', 'sron2012', 'mathematica',
-        'oregon', 'ncl', 'matplotlib', and 'brewer'.
+        'oregon', 'ipcc', 'ncl', 'matplotlib', and 'brewer'.
 
     Returns
     -------
@@ -646,9 +695,14 @@ def show_palettes(outfile='', collection=''):  # pragma: no cover
     import matplotlib as mpl
     import matplotlib.pyplot as plt
     import pyjams.color
+    warn('The plotting functions of pyjams were transferred to a'
+         ' standalone repository "mcplot". show_palettes is hence deprecated'
+         ' in pyjams.',
+         category=DeprecationWarning)
+
     # outtype
     if '.' in outfile:
-        outtype = outfile[outfile.rfind('.')+1:]
+        outtype = outfile[outfile.rfind('.') + 1:]
         if outtype == 'pdf':
             mpl.use('PDF')  # set directly after import matplotlib
             from matplotlib.backends.backend_pdf import PdfPages
@@ -659,11 +713,10 @@ def show_palettes(outfile='', collection=''):  # pragma: no cover
     else:
         outtype = 'X'
         textsize = 8
-    import matplotlib.pyplot as plt
 
     # which collections to include
     collections = ['pyjams', 'sron', 'sron2012', 'mathematica', 'oregon',
-                   'ncl', 'matplotlib', 'brewer']
+                   'ipcc', 'ncl', 'matplotlib', 'brewer']
     if collection:
         if isinstance(collection, str):
             if collection.lower() != 'all':
@@ -677,8 +730,8 @@ def show_palettes(outfile='', collection=''):  # pragma: no cover
         if not (outtype == 'pdf'):
             mpl.rc('savefig', dpi=300, format=outtype)
     else:
-        mpl.rc('figure', figsize=(8.27*0.75, 11.69*0.75))
-    figsize = mpl.rcParams['figure.figsize']
+        mpl.rc('figure', figsize=(8.27 * 0.75, 11.69 * 0.75))
+    # figsize = mpl.rcParams['figure.figsize']
     mpl.rc('font', size=textsize)
     nrow = 35
 
@@ -698,6 +751,9 @@ def show_palettes(outfile='', collection=''):  # pragma: no cover
     oregon_collections = [ i for i in dir(pyjams.color)
                            if i.startswith('oregon_')
                            and not i.endswith('_palettes') ]
+    ipcc_collections = [ i for i in dir(pyjams.color)
+                         if i.startswith('ipcc_')
+                         and not i.endswith('_palettes') ]
     ncl_collections = [ i for i in dir(pyjams.color)
                         if i.startswith('ncl_')
                         and not i.endswith('_palettes') ]
@@ -721,6 +777,9 @@ def show_palettes(outfile='', collection=''):  # pragma: no cover
     if 'oregon' in collections:
         for cc in oregon_collections:
             all_collections.append(cc)
+    if 'ipcc' in collections:
+        for cc in ipcc_collections:
+            all_collections.append(cc)
     if 'ncl' in collections:
         for cc in ncl_collections:
             all_collections.append(cc)
