@@ -52,7 +52,6 @@ History
     * More consistent docstrings, Jan 2022, Matthias Cuntz
 
 """
-from __future__ import division, absolute_import, print_function
 import numpy as np
 
 
@@ -81,12 +80,13 @@ def ackley(x):
     """
     a = 20.0
     b = 0.2
-    c = 2.0*np.pi
+    c = 2.0 * np.pi
 
     n  = np.size(x)
     s1 = np.sum(x**2)
-    s2 = np.sum(np.cos(c*x))
-    f  = -a * np.exp(-b*np.sqrt(1.0/n*s1)) - np.exp(1.0/n*s2) + a + np.exp(1.0)
+    s2 = np.sum(np.cos(c * x))
+    f  = (-a * np.exp(-b * np.sqrt(1.0 / n * s1)) - np.exp(1.0 / n * s2) + a +
+          np.exp(1.0))
 
     return f
 
@@ -123,8 +123,8 @@ def griewank(x):
     u1 = 0.0
     u2 = 1.0
     for j in range(nopt):
-        u1 = u1 + xx[j]**2/d
-        u2 = u2 * np.cos(xx[j]/np.sqrt(float(j+1)))
+        u1 = u1 + xx[j]**2 / d
+        u2 = u2 * np.cos(xx[j] / np.sqrt(float(j + 1)))
 
     f = u1 - u2 + 1
     return f
@@ -153,9 +153,9 @@ def goldstein_price(x):
     x1 = x[0]
     x2 = x[1]
     u1 = (x1 + x2 + 1.0)**2
-    u2 = 19. - 14.*x1 + 3.*x1**2 - 14.*x2 + 6.*x1*x2 + 3.*x2**2
-    u3 = (2.*x1 - 3.*x2)**2
-    u4 = 18. - 32.*x1 + 12.*x1**2 + 48.*x2 - 36.*x1*x2 + 27.*x2**2
+    u2 = 19. - 14. * x1 + 3. * x1**2 - 14. * x2 + 6. * x1 * x2 + 3. * x2**2
+    u3 = (2. * x1 - 3. * x2)**2
+    u4 = 18. - 32. * x1 + 12. * x1**2 + 48. * x2 - 36. * x1 * x2 + 27. * x2**2
     u5 = u1 * u2
     u6 = u3 * u4
     f = (1. + u5) * (30. + u6)
@@ -184,7 +184,7 @@ def rastrigin(x):
     """
     x1 = x[0]
     x2 = x[1]
-    f = x1**2 + x2**2 - np.cos(18.0*x1) - np.cos(18.0*x2)
+    f = x1**2 + x2**2 - np.cos(18.0 * x1) - np.cos(18.0 * x2)
     return f
 
 
@@ -240,7 +240,8 @@ def six_hump_camelback(x):
     """
     x1 = x[0]
     x2 = x[1]
-    f = (4 - 2.1*x1**2 + x1**4/3)*x1**2 + x1*x2 + (-4 + 4*x2**2)*x2**2
+    f = ((4 - 2.1 * x1**2 + x1**4 / 3.) * x1**2 + x1 * x2 +
+         (-4 + 4 * x2**2) * x2**2)
     return f
 
 
