@@ -150,8 +150,8 @@ def B(X):
 
     assert iX.shape[0] % 2 == 0, 'X.shape[0] must be even.'
 
-    m  = iX.shape[0]//2
-    y  = np.sum(iX[:m, :]*iX[m:, :], axis=0)
+    m  = iX.shape[0] // 2
+    y  = np.sum(iX[:m, :] * iX[m:, :], axis=0)
 
     if isone:
         return y[0]
@@ -265,9 +265,9 @@ def Gstar(X, alpha, delta, a):
     ialpha = np.array(alpha).reshape((nalpha, 1))
     idelta = np.array(delta).reshape((nalpha, 1))
     ia     = np.array(a).reshape((nalpha, 1))
-    yi = ( ( (1.+ialpha) *
-             np.abs(2.*(iX+idelta-np.trunc(iX+idelta))-1.)**ialpha+ia) /
-           (1.+ia) )
+    yi = ( ( (1. + ialpha) *
+             np.abs(2. * (iX + idelta - np.trunc(iX + idelta)) - 1.)**ialpha +
+             ia ) / (1. + ia) )
     y  = np.prod(yi, axis=0)
 
     if isone:
@@ -504,8 +504,8 @@ def ishigami_homma(X, a, b):
 
     assert iX.shape[0] == 3, 'X.shape[0] must be 3.'
 
-    y = (np.sin(iX[0, :]) + a*(np.sin(iX[1, :]))**2 +
-         b*iX[2, :]**4 * np.sin(iX[0, :]))
+    y = (np.sin(iX[0, :]) + a * (np.sin(iX[1, :]))**2 +
+         b * iX[2, :]**4 * np.sin(iX[0, :]))
 
     if isone:
         return y[0]
@@ -548,9 +548,9 @@ def K(X):
 
     nX = iX.shape[0]
     for ii in range(1, nX):
-        iX[ii, :] = iX[ii-1, :] * iX[ii, :]
+        iX[ii, :] = iX[ii - 1, :] * iX[ii, :]
     for ii in range(nX):
-        iX[ii, :] = (-1)**(ii+1) * iX[ii, :]
+        iX[ii, :] = (-1)**(ii + 1) * iX[ii, :]
     y = iX.sum(axis=0)
 
     if isone:
@@ -618,31 +618,31 @@ def fmorris(X, beta0, beta1, beta2, beta3, beta4):
         isone = False
         iX = X
 
-    om = 2.*(iX - 0.5)
+    om = 2. * (iX - 0.5)
     ii = np.array((2, 4, 6))
-    om[ii, :] = 2.*(1.1*iX[ii, :]/(iX[ii, :]+0.1) - 0.5)
+    om[ii, :] = 2. * (1.1 * iX[ii, :] / (iX[ii, :] + 0.1) - 0.5)
 
     nn  = 20
 
-    assert iX.shape[0] == nn, 'X.shape[0] must '+str(nn)+'.'
+    assert iX.shape[0] == nn, 'X.shape[0] must ' + str(nn) + '.'
     assert np.all(np.array(beta1.shape) == nn), (
-        'beta1.shape must be all '+str(nn)+'.')
+        'beta1.shape must be all ' + str(nn) + '.')
     assert np.all(np.array(beta2.shape) == nn), (
-        'beta2.shape must be all '+str(nn)+'.')
+        'beta2.shape must be all ' + str(nn) + '.')
     assert np.all(np.array(beta3.shape) == nn), (
-        'beta3.shape must be all '+str(nn)+'.')
+        'beta3.shape must be all ' + str(nn) + '.')
     assert np.all(np.array(beta4.shape) == nn), (
-        'beta4.shape must be all '+str(nn)+'.')
+        'beta4.shape must be all ' + str(nn) + '.')
 
     y    = np.empty(iX.shape[1])
     y[:] = beta0
     for i in range(0, nn):
-        y[:] += beta1[i]*om[i, :]
-        for j in range(i+1, nn):
-            y[:] += beta2[i, j]*om[i, :]*om[j, :]
-            for k in range(j+1, nn):
-                y[:] += beta3[i, j, k]*om[i, :]*om[j, :]*om[k, :]
-                for s in range(k+1, nn):
+        y[:] += beta1[i] * om[i, :]
+        for j in range(i + 1, nn):
+            y[:] += beta2[i, j] * om[i, :] * om[j, :]
+            for k in range(j + 1, nn):
+                y[:] += beta3[i, j, k] * om[i, :] * om[j, :] * om[k, :]
+                for s in range(k + 1, nn):
                     y[:] += (beta4[i, j, k, s] *
                              om[i, :] * om[j, :] * om[k, :] * om[s, :])
 
@@ -713,7 +713,7 @@ def oakley_ohagan(X):
 
     nn = 15
 
-    assert iX.shape[0] == nn, 'X.shape[0] must '+str(nn)+'.'
+    assert iX.shape[0] == nn, 'X.shape[0] must ' + str(nn) + '.'
 
     a1 = np.array([0.01, 0.05, 0.23, 0.04, 0.12, 0.39, 0.39, 0.61, 0.62, 0.40,
                    1.07, 1.15, 0.79, 1.12, 1.20])
@@ -722,36 +722,36 @@ def oakley_ohagan(X):
     a3 = np.array([0.10, 0.21, 0.08, 0.27, 0.13, 0.75, 0.86, 1.03, 0.84, 0.80,
                    2.21, 2.04, 2.40, 2.05, 1.98])
     M  = np.array([
-        [-0.02, -0.19,   0.13,  0.37,  0.17,  0.14, -0.44,  -0.08,  0.71,
-         -0.44,  0.5,  -0.02, -0.05,  0.22,  0.06],
-        [ 0.26,  0.05,   0.26,  0.24, -0.59, -0.08, -0.29,   0.42,  0.5,
-          0.08, -0.11,  0.03, -0.14, -0.03, -0.22],
-        [-0.06,  0.2,    0.1,  -0.29, -0.14,  0.22,  0.15,   0.29,  0.23,
-         -0.32, -0.29, -0.21,  0.43,  0.02,  0.04],
-        [ 0.66,  0.43,   0.3,  -0.16, -0.31, -0.39,  0.18,   0.06,  0.17,
-          0.13, -0.35,  0.25, -0.02,  0.36, -0.33],
-        [-0.12,  0.12,   0.11,  0.05, -0.22,  0.19, -0.07,   0.02, -0.1,
-         0.19,  0.33,  0.31, -0.08, -0.25,  0.37],
-        [-0.28, -0.33,  -0.1,  -0.22, -0.14, -0.14, -0.12,   0.22, -0.03,
-         -0.52,  0.02,  0.04,  0.36,  0.31,  0.05],
-        [-0.08,  0.004,  0.89, -0.27, -0.08, -0.04, -0.19,  -0.36, -0.17,
-         0.09,  0.4,  -0.06,  0.14,  0.21, -0.01],
-        [-0.09,  0.59,   0.03, -0.03, -0.24, -0.1,   0.03,   0.1,  -0.34,
-         0.01, -0.61,  0.08,  0.89,  0.14,  0.15],
-        [-0.13,  0.53,   0.13,  0.05,  0.58,  0.37,  0.11,  -0.29, -0.57,
-         0.46, -0.09,  0.14, -0.39, -0.45, -0.15],
-        [ 0.06, -0.32,   0.09,  0.07, -0.57,  0.53,  0.24,  -0.01,  0.07,
-          0.08, -0.13,  0.23,  0.14, -0.45, -0.56],
-        [ 0.66,  0.35,   0.14,  0.52, -0.28, -0.16, -0.07,  -0.2,   0.07,
-          0.23, -0.04, -0.16,  0.22,  0,    -0.09],
-        [ 0.32, -0.03,   0.13,  0.13,  0.05, -0.17,  0.18,   0.06, -0.18,
-          -0.31, -0.25,  0.03, -0.43, -0.62, -0.03],
-        [-0.29,  0.03,   0.03, -0.12,  0.03, -0.34, -0.41,   0.05, -0.27,
-         -0.03,  0.41,  0.27,  0.16, -0.19,  0.02],
-        [-0.24, -0.44,   0.01,  0.25,  0.07,  0.25,  0.17,   0.01,  0.25,
-         -0.15, -0.08,  0.37, -0.3,   0.11, -0.76],
-        [ 0.04, -0.26,   0.46, -0.36, -0.95, -0.17,  0.003,  0.05,  0.23,
-          0.38,  0.46, -0.19,  0.01,  0.17,  0.16] ])
+        [-0.02, -0.19, 0.13, 0.37, 0.17, 0.14, -0.44, -0.08, 0.71,
+         -0.44, 0.5, -0.02, -0.05, 0.22, 0.06],
+        [ 0.26, 0.05, 0.26, 0.24, -0.59, -0.08, -0.29, 0.42, 0.5,
+          0.08, -0.11, 0.03, -0.14, -0.03, -0.22],
+        [-0.06, 0.2, 0.1, -0.29, -0.14, 0.22, 0.15, 0.29, 0.23,
+         -0.32, -0.29, -0.21, 0.43, 0.02, 0.04],
+        [ 0.66, 0.43, 0.3, -0.16, -0.31, -0.39, 0.18, 0.06, 0.17,
+          0.13, -0.35, 0.25, -0.02, 0.36, -0.33],
+        [-0.12, 0.12, 0.11, 0.05, -0.22, 0.19, -0.07, 0.02, -0.1,
+         0.19, 0.33, 0.31, -0.08, -0.25, 0.37],
+        [-0.28, -0.33, -0.1, -0.22, -0.14, -0.14, -0.12, 0.22, -0.03,
+         -0.52, 0.02, 0.04, 0.36, 0.31, 0.05],
+        [-0.08, 0.004, 0.89, -0.27, -0.08, -0.04, -0.19, -0.36, -0.17,
+         0.09, 0.4, -0.06, 0.14, 0.21, -0.01],
+        [-0.09, 0.59, 0.03, -0.03, -0.24, -0.1, 0.03, 0.1, -0.34,
+         0.01, -0.61, 0.08, 0.89, 0.14, 0.15],
+        [-0.13, 0.53, 0.13, 0.05, 0.58, 0.37, 0.11, -0.29, -0.57,
+         0.46, -0.09, 0.14, -0.39, -0.45, -0.15],
+        [ 0.06, -0.32, 0.09, 0.07, -0.57, 0.53, 0.24, -0.01, 0.07,
+          0.08, -0.13, 0.23, 0.14, -0.45, -0.56],
+        [ 0.66, 0.35, 0.14, 0.52, -0.28, -0.16, -0.07, -0.2, 0.07,
+          0.23, -0.04, -0.16, 0.22, 0, -0.09],
+        [ 0.32, -0.03, 0.13, 0.13, 0.05, -0.17, 0.18, 0.06, -0.18,
+          -0.31, -0.25, 0.03, -0.43, -0.62, -0.03],
+        [-0.29, 0.03, 0.03, -0.12, 0.03, -0.34, -0.41, 0.05, -0.27,
+         -0.03, 0.41, 0.27, 0.16, -0.19, 0.02],
+        [-0.24, -0.44, 0.01, 0.25, 0.07, 0.25, 0.17, 0.01, 0.25,
+         -0.15, -0.08, 0.37, -0.3, 0.11, -0.76],
+        [ 0.04, -0.26, 0.46, -0.36, -0.95, -0.17, 0.003, 0.05, 0.23,
+          0.38, 0.46, -0.19, 0.01, 0.17, 0.16] ])
 
     y = np.dot(a1, iX) + np.dot(a2, np.sin(iX)) + np.dot(a3, np.cos(iX))
     for i in range(iX.shape[1]):
