@@ -6,8 +6,7 @@ It has the same functionality as the old mc_template.py by Matthias Cuntz but
 uses the object-oriented approach of st_template.py of Stephan Thober.
 
 It allows plotting on screen, into PDF and PNG files, as well as in HTML
-files as a wrapper for PNG images or in D3 format (and plotly currently only
-with older Matplotlib versions).
+files as a wrapper for PNG images or using hvplot.
 
 It is optimised for publication ready plots, either on white or black
 background.
@@ -75,7 +74,7 @@ This module was written by Matthias Cuntz while at Institut National de
 Recherche pour l'Agriculture, l'Alimentation et l'Environnement (INRAE), Nancy,
 France.
 
-:copyright: Copyright 2020-2022 Matthias Cuntz, see AUTHORS.rst for details.
+:copyright: Copyright 2020- Matthias Cuntz, see AUTHORS.rst for details.
 :license: MIT License, see LICENSE for details.
 
 .. moduleauthor:: Matthias Cuntz
@@ -96,33 +95,28 @@ History
     * Add left, bottom, top to standard layout options,
       Jul 2022, Matthias Cuntz
     * Add --dpi as a standard option, Jan 2023, Matthias Cuntz
+    * Use helper.filebase, Mar 2023, Matthias Cuntz
+    * Replace plotly with hvplot, May 2023, Matthias Cuntz
+    * Set filename without suffix as default plot name,
+      Jun 2023, Matthias Cuntz
+    * Removed space from print of plot filename, Jun 2023, Matthias Cuntz
+    * Set default options if not given on command line,
+      Jan 2024, Matthias Cuntz
+    * Add method print_layout_options, Mar 2024, Matthias Cuntz
+    * Use DejaVuSans and DejaVueSerif as standard fonts if not LaTeX
+      because they come with matplotlib, May 2024, Matthias Cuntz
+    * parents argument to ArgumentParser, Jul 2024, Matthias Cuntz
 
 """
 import numpy as np
+from .helper import filebase
+from warnings import warn, filterwarnings
+filterwarnings("default", category=DeprecationWarning)
 
 
 __all__ = ['mcPlot']
 
 
-# -------------------------------------------------------------------------
-# Helper functions
-#
-
-
-def _filebase(f):
-    f1 = f
-    if f.startswith('..'):
-        f1 = f[2:]
-    elif f.startswith('.'):
-        f1 = f[1:]
-    else:
-        f1 = f
-    if '.' in f1:
-        return f[0:f.rfind(".")]
-    else:
-        return f
-
-
 # -------------------------------------------------------------------------
 # Class mcPlot
 #
@@ -145,14 +139,20 @@ class mcPlot(object):
         called with -h.
     argstr : string, optional
         String given as description for the positional arguments.
+    parents : ArgumentParser or list, optional
+        ArgumentParser or list of ArgumentParser objects whose arguments
+        should also be included.
+        Note, these parsers should be initialised with `add_help=False`.
+        Otherwise, the ArgumentParser will see two -h/--help options
+        and raise an error.
 
     Methods
     -------
-    get_command_line_arguments(desc=None, argstr=None)
+    get_command_line_arguments(desc=None, argstr=None, parents=[])
         Standard command line parser with the default arguments
         such as plot type, filename, etc. If extra arguments are needed,
-        one should copy this routine into the extending class and adapt
-        it to its needs, keeping the existing optional arguments.
+        one can pass an ArgumentParser as parent, which was initialised
+        with `add_help=False`.
     plot_end() or plot_stop() or plot_close() or end() or stop()
         Finish, closing opened output files.
     plot_save(fig, **kwargs)
@@ -174,6 +174,9 @@ class mcPlot(object):
     plot_test()
         A simple plot as an example.
 
+    print_layout_options(rcparams=False)
+        Prints current layout options and optionally matplotlib''s rcParams.
+
     set_matplotlib_rcparams()
         Set rcParams of Matplotlib depending on output type, and chosen layout.
         rcParams can also be re-set in the initialisation of the extending
@@ -243,7 +246,7 @@ class mcPlot(object):
     # -------------------------------------------------------------------------
     # init
     #
-    def __init__(self, desc=None, argstr=None):
+    def __init__(self, desc=None, argstr=None, parents=[]):
         """
         Initialise the class mcPlot.
 
@@ -264,8 +267,13 @@ class mcPlot(object):
                    super().__init__(*args, **kwargs)`
 
         """
+        warn('The plotting functions of pyjams were transferred to a'
+             ' standalone repository "mcplot". mcPlot is hence deprecated'
+             ' in pyjams.',
+             category=DeprecationWarning)
         # get options
-        self.get_command_line_arguments(desc=desc, argstr=argstr)
+        self.get_command_line_arguments(desc=desc, argstr=argstr,
+                                        parents=parents)
         # pdf, png, ...
         self.set_output_type()
         # nrow, ncol, colours, etc.
@@ -278,7 +286,7 @@ class mcPlot(object):
     # -------------------------------------------------------------------------
     # command line arguments
     #
-    def get_command_line_arguments(self, desc=None, argstr=None):
+    def get_command_line_arguments(self, desc=None, argstr=None, parents=[]):
         """
         Standard command line parser with default arguments
         such as plot type, filename, etc.
@@ -294,6 +302,12 @@ class mcPlot(object):
             called with -h.
         argstr : string, optional
             String given as description for the positional arguments.
+        parents : ArgumentParser or list, optional
+            ArgumentParser or list of ArgumentParser objects whose arguments
+            should also be included.
+            Note, these parsers should be initialised with `add_help=False`.
+            Otherwise, the ArgumentParser will see two -h/--help options
+            and raise an error.
 
         Notes
         -----
@@ -308,12 +322,12 @@ class mcPlot(object):
              -h, --help            show this help message and exit
              -p plotname, --plotname plotname
                                    Name of plot output file for types pdf,
-                                   html, d3, or plotly, and name basis for type
+                                   html, d3, or hvplot, and name basis for type
                                    png (default: calling_filename without
                                    extension).
              -s, --serif           Use serif font; default sans serif.
              -t outtype, --type outtype
-                                   Output type is pdf, png, html, d3, or plotly
+                                   Output type is pdf, png, html, d3, or hvplot
                                    (default: open screen windows).
              -u, --usetex          Use LaTeX to render text in pdf, png and
                                    html.
@@ -346,27 +360,30 @@ class mcPlot(object):
         else:
             iargstr = argstr
 
-        plotname = ''
+        plotname = filebase(os.path.basename(__file__))
         serif    = False
         outtype  = ''
         transparent = False
         usetex   = False
         dowhite  = False
         dpi      = 300
+        try:
+            _ = len(parents)
+        except TypeError:
+            parents = [parents]
         parser = argparse.ArgumentParser(
             formatter_class=argparse.RawDescriptionHelpFormatter,
-            description=idesc)
-        default = _filebase(os.path.basename(__file__))
+            description=idesc, parents=parents)
         hstr = (f'Name of plot output file for types pdf, html, d3, or'
-                f' plotly, and name basis for type png (default:'
-                f' {default}).')
+                f' hvplot, and name basis for type png (default:'
+                f' {plotname}).')
         parser.add_argument('-p', '--plotname', action='store',
                             default=plotname, dest='plotname',
                             metavar='plotname', help=hstr)
         hstr = 'Use serif font; default sans serif.'
         parser.add_argument('-s', '--serif', action='store_true',
                             default=serif, dest='serif', help=hstr)
-        hstr = ('Output type is pdf, png, html, d3, or plotly'
+        hstr = ('Output type is pdf, png, html, d3, or hvplot'
                 ' (default: open screen windows).')
         parser.add_argument('-t', '--type', action='store', default=outtype,
                             dest='outtype', metavar='outtype', help=hstr)
@@ -377,8 +394,6 @@ class mcPlot(object):
                 ' default: black lines on transparent or white background.')
         parser.add_argument('-w', '--white', action='store_true',
                             default=dowhite, dest='dowhite', help=hstr)
-        parser.add_argument('cargs', nargs='*', default=None,
-                            metavar='args', help=iargstr)
         hstr = ('Dots Per inch (DPI) for non-vector output types or rasterized'
                 ' maps in vector output (default: 300).')
         parser.add_argument('--dpi', action='store', default=dpi, type=int,
@@ -386,17 +401,24 @@ class mcPlot(object):
         hstr = ('Transparent figure background (default: black or white).')
         parser.add_argument('--transparent', action='store_true',
                             default=transparent, dest='transparent', help=hstr)
+        parser.add_argument('cargs', nargs='*', default=None,
+                            metavar='args', help=iargstr)
 
         args = parser.parse_args()
 
-        self.args        = args.cargs
-        self.plotname    = args.plotname
-        self.serif       = args.serif
-        self.outtype     = args.outtype
-        self.usetex      = args.usetex
-        self.dowhite     = args.dowhite
-        self.dpi         = args.dpi
-        self.transparent = args.transparent
+        # self.plotname    = args.plotname
+        # self.serif       = args.serif
+        # self.outtype     = args.outtype
+        # self.usetex      = args.usetex
+        # self.dowhite     = args.dowhite
+        # self.dpi         = args.dpi
+        # self.transparent = args.transparent
+        for arg in args.__dict__:
+            setattr(self, arg, args.__dict__[arg])
+        # for backward compatibility
+        # self.args        = args.cargs
+        if 'cargs' in args.__dict__:
+            setattr(self, 'args', args.__dict__['cargs'])
 
         del parser, args
 
@@ -503,8 +525,8 @@ class mcPlot(object):
            * - self.transparent
              - True for transparent background in figure
            * - self.bbox_inches
-             - Bbox in inches. If 'tight', try to figure out the tight bbox of the
-               figure
+             - Bbox in inches. If 'tight', try to figure out the tight bbox of
+               the figure
            * - self.pad_inches
              - Amount of padding when bbox_inches is 'tight'
 
@@ -523,6 +545,9 @@ class mcPlot(object):
                    self.set_matplotlib_rcparams()
 
         """
+        if not hasattr(self, 'dowhite'):
+            self.dowhite = False
+
         # layout and spaces
         self.nrow     = 3     # # of rows of subplots per figure
         self.ncol     = 2     # # of columns of subplots per figure
@@ -599,6 +624,16 @@ class mcPlot(object):
         # self.dpi         = 300
         self.bbox_inches = 'tight'
         self.pad_inches  = 0.035
+        if not hasattr(self, 'dpi'):
+            self.dpi = 300
+        if not hasattr(self, 'transparent'):
+            self.transparent = False
+
+        # misc
+        if not hasattr(self, 'serif'):
+            self.serif = False
+        if not hasattr(self, 'usetex'):
+            self.usetex = False
 
     # -------------------------------------------------------------------------
     # test figure
@@ -616,7 +651,7 @@ class mcPlot(object):
         fig = plt.figure(self.ifig)
 
         nn = 100
-        xx = np.arange(nn) / float(nn) * 4.*np.pi
+        xx = np.arange(nn) / float(nn) * 4. * np.pi
         yy1 = np.sin(xx)
         yy2 = np.cos(xx)
 
@@ -673,15 +708,19 @@ class mcPlot(object):
         """
         Set type of chosen output.
 
-        Fall back to standard html mode if mlpd3 or plotly modules are not
+        Fall back to standard html mode if mlpd3 or hvplot modules are not
         installed.
 
         """
+        self.outtypes = ['', 'pdf', 'png', 'html', 'd3', 'hvplot']
+        self.outtype_ends = ['', '.pdf', '_', '.html', '.html', '.html']
+        if not hasattr(self, 'outtype'):
+            self.outtype = ''
+
         self.outtype  = self.outtype.lower()
-        self.outtypes = ['', 'pdf', 'png', 'html', 'd3', 'plotly']
         if self.outtype not in self.outtypes:
-            estr  = '\nOutput ' + self.outtype + ' type must be in:'
-            raise IOError(estr, self.outtypes)
+            raise IOError(f'Output {self.outtype} type must be in:'
+                          f'{self.outtypes}')
 
         if (self.outtype == 'd3'):
             try:
@@ -690,16 +729,12 @@ class mcPlot(object):
                 print("    No mpld3 found. Use output type html instead.")
                 self.outtype = 'html'
 
-        if (self.outtype == 'plotly'):
+        if (self.outtype == 'hvplot'):
             try:
-                import plotly.tools
-                import plotly.offline
+                import hvplot
             except ModuleNotFoundError:
-                print("    No plotly found. Use output type html instead.")
-                outtype = 'html'
-            if (self.outtype == 'plotly') and (self.plotname != ''):
-                assert self.plotname.endswith('html'), (
-                    'Plotly plotnames must end with .html')
+                raise IOError('Module hvplot not found')
+            self.usetex = False
 
     # -------------------------------------------------------------------------
     # Matplotlib defaults
@@ -777,7 +812,8 @@ class mcPlot(object):
                     #   r'\usepackage{helvet}',  # use Helvetica
                     mpl.rcParams['text.latex.preamble'] = '\n'.join([
                         # use MyriadPro font
-                        r'\usepackage[math,lf,mathtabular,footnotefigures]{MyriadPro}',
+                        r'\usepackage[math,lf,mathtabular,footnotefigures]'
+                        r'{MyriadPro}',
                         # normal text font is sans serif
                         r'\renewcommand{\familydefault}{\sfdefault}',
                         r'\figureversion{lining,tabular}',
@@ -792,12 +828,12 @@ class mcPlot(object):
             else:
                 if self.serif:
                     mpl.rcParams['font.family']     = 'serif'
-                    mpl.rcParams['font.sans-serif'] = 'Times'
+                    mpl.rcParams['font.sans-serif'] = 'DejaVu Serif'
                 else:
                     mpl.rcParams['font.family']     = 'sans-serif'
-                    mpl.rcParams['font.sans-serif'] = 'Arial'  # Arial, Verdana
+                    mpl.rcParams['font.sans-serif'] = 'DejaVu Sans'
         elif ((self.outtype == 'png') or (self.outtype == 'html') or
-              (self.outtype == 'd3') or (self.outtype == 'plotly')):
+              (self.outtype == 'd3') or (self.outtype == 'hvplot')):
             mpl.use('Agg')  # set directly after import matplotlib
             mpl.rc('figure', figsize=(8.27, 11.69))  # a4 portrait
             if self.usetex:
@@ -806,7 +842,8 @@ class mcPlot(object):
                     #   r'\usepackage{helvet}',  # use Helvetica
                     mpl.rcParams['text.latex.preamble'] = '\n'.join([
                         # use MyriadPro font
-                        r'\usepackage[math,lf,mathtabular,footnotefigures]{MyriadPro}',
+                        r'\usepackage[math,lf,mathtabular,footnotefigures]'
+                        r'{MyriadPro}',
                         # normal text font is sans serif
                         r'\renewcommand{\familydefault}{\sfdefault}',
                         r'\figureversion{lining,tabular}',
@@ -821,13 +858,14 @@ class mcPlot(object):
             else:
                 if self.serif:
                     mpl.rcParams['font.family']     = 'serif'
-                    mpl.rcParams['font.sans-serif'] = 'Times'
+                    mpl.rcParams['font.sans-serif'] = 'DejaVu Serif'
                 else:
                     mpl.rcParams['font.family']     = 'sans-serif'
-                    mpl.rcParams['font.sans-serif'] = 'Arial'  # Arial, Verdana
+                    mpl.rcParams['font.sans-serif'] = 'DejaVu Sans'
             mpl.rc('savefig', dpi=self.dpi, format='png')
         else:
-            mpl.rc('figure', figsize=(4./5.*8.27, 4./5.*11.69))  # a4 portrait
+            # a4 portrait
+            mpl.rc('figure', figsize=(4. / 5. * 8.27, 4. / 5. * 11.69))
         # print(mpl.rcParams)
         mpl.rc('axes', linewidth=self.alwidth, edgecolor=self.fgcolor,
                facecolor=self.bgcolor, labelcolor=self.fgcolor,
@@ -864,36 +902,74 @@ class mcPlot(object):
         if appropriate.
 
         """
-        self.outtype_ends = ['', '.pdf', '_', '.html', '.html']
         if self.plotname == '':
-            self.plotfile  = (_filebase(os.path.basename(__file__)) +
+            self.plotfile  = (filebase(os.path.basename(__file__)) +
                               self.outtype_ends[
                                   self.outtypes.index(self.outtype)])
         else:
             self.plotfile = self.plotname
+
         if self.outtype == '':
             print('    Plot X')
         else:
-            print('    Plot ', self.plotfile)
+            print('    Plot', self.plotfile)
 
         if (self.outtype == 'pdf'):
             self.pdf_pages = self.PdfPages(self.plotfile)
-        # figsize = mpl.rcParams['figure.figsize']
-
-        if self.outtype in ['html', 'd3']:
+            # figsize = mpl.rcParams['figure.figsize']
+        elif self.outtype in ['html', 'd3']:
             print('    Write html file ', self.plotfile)
             self.fhtml = open(self.plotfile, 'w')
-            fstr  = '<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01'
-            fstr += ' Transitional//EN">'
-            print(fstr, file=self.fhtml)
-            print("<html>", file=self.fhtml)
-            print("<head>", file=self.fhtml)
-            print("<title>"+self.plotfile+"</title>", file=self.fhtml)
-            print("</head>", file=self.fhtml)
-            print("<body>", file=self.fhtml)
-
-        if (self.outtype == 'plotly'):
-            self.htmlfiles = []
+            print(f'<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01'
+                  f' Transitional//EN">\n'
+                  f' "http://www.w3.org/TR/html4/loose.dtd">\n'
+                  f'<html>\n'
+                  f'    <head>\n'
+                  f'        <title>{self.plotfile}</title>\n'
+                  f'    </head>\n'
+                  f'    <body>\n',
+                  file=self.fhtml)
+        elif (self.outtype == 'hvplot'):
+            print('    Write html file ', self.plotfile)
+            with open(self.plotfile, 'w') as ff:
+                print(f'<!DOCTYPE html public "-//W3C//DTD HTML'
+                      f' 4.01 Frameset//EN"\n'
+                      f' "http://www.w3.org/TR/html4/frameset.dtd">\n'
+                      f'<html>\n'
+                      f'    <head>\n'
+                      f'        <title>{self.plotfile}</title>\n'
+                      f'    </head>\n'
+                      f'    <frameset cols="15%, 85%">\n'
+                      f'        <frame name="fixed" src="html/menu.html">\n'
+                      f'        <frame name="dynamic" src="html/empty.html">\n'
+                      f'    </frameset>\n'
+                      f'</html>', file=ff)
+            ibase = os.path.dirname(self.plotfile)
+            if not ibase:
+                ibase = './'
+            else:
+                ibase += '/'
+            if not os.path.exists(ibase + 'html'):
+                os.mkdir(ibase + 'html')
+            with open(ibase + 'html/empty.html', 'w') as ff:
+                print('<!DOCTYPE html public "-//W3C//DTD HTML 4.01'
+                      ' Frameset//EN"\n'
+                      ' "http://www.w3.org/TR/html4/frameset.dtd">\n'
+                      '<html>\n'
+                      '    <body>\n'
+                      '    </body>\n'
+                      '</html>', file=ff)
+            self.fhtml = open(ibase + 'html/menu.html', 'w')
+            print(f'<!DOCTYPE html public "-//W3C//DTD HTML'
+                  f' 4.01 Transitional//EN"\n'
+                  f' "http://www.w3.org/TR/html4/loose.dtd">\n'
+                  f'<html>\n'
+                  f'    <head>\n'
+                  f'        <title>{self.plotfile}</title>\n'
+                  f'        <base href="html" target="dynamic">\n'
+                  f'    </head>\n'
+                  f'    <body>\n',
+                  file=self.fhtml)
 
         self.ifig = 0
 
@@ -915,9 +991,8 @@ class mcPlot(object):
         kwargs : dict, optional
             Additional keywords will be passed to *savefig* for 'pdf',
             'png', and 'html'; to *fig_to_html* for 'd3', and to
-            *offline.plot* for 'plotly'. This overwrites *self.transparent*,
-            *self.bbox_inches*, *self.pad_inches* for 'pdf', 'png', and 'html',
-            and *auto_open=False* for 'plotly'.
+            *save* for 'hvplot'. This overwrites *self.transparent*,
+            *self.bbox_inches*, *self.pad_inches* for 'pdf', 'png', and 'html'.
 
         """
         import matplotlib.pyplot as plt
@@ -928,7 +1003,7 @@ class mcPlot(object):
             self.pdf_pages.savefig(fig, **kwargs)
             plt.close(fig)
         elif (self.outtype == 'png'):
-            pngfile = self.plotfile+"{0:04d}".format(self.ifig)+".png"
+            pngfile = self.plotfile + "{0:04d}".format(self.ifig) + ".png"
             if 'transparent' not in kwargs:
                 kwargs.update({'transparent': self.transparent})
             if 'bbox_inches' not in kwargs:
@@ -938,7 +1013,7 @@ class mcPlot(object):
             fig.savefig(pngfile, **kwargs)
             plt.close(fig)
         elif (self.outtype == 'html'):
-            pngfile  = _filebase(self.plotfile) + "_"
+            pngfile  = filebase(self.plotfile) + "_"
             pngfile += "{0:04d}".format(self.ifig) + ".png"
             if 'transparent' not in kwargs:
                 kwargs.update({'transparent': self.transparent})
@@ -947,7 +1022,7 @@ class mcPlot(object):
             if 'pad_inches' not in kwargs:
                 kwargs.update({'pad_inches': self.pad_inches})
             fig.savefig(pngfile, **kwargs)
-            print('<p><img src='+pngfile+'></p>', file=self.fhtml)
+            print('<p><img src=' + pngfile + '></p>', file=self.fhtml)
             plt.close(fig)
         elif (self.outtype == 'd3'):
             import mpld3
@@ -956,16 +1031,56 @@ class mcPlot(object):
             d3str = mpld3.fig_to_html(fig, **kwargs)
             print(d3str, file=self.fhtml)
             plt.close(fig)
-        elif (self.outtype == 'plotly'):
-            import plotly.tools
-            import plotly.offline
-            htmlfile = self.plotfile+"{0:04d}".format(self.ifig)+".html"
-            plotly_fig = plotly.tools.mpl_to_plotly(fig)
-            if 'auto_open' not in kwargs:
-                kwargs.update({'auto_open': False})
-            ff = plotly.offline.plot(plotly_fig, filename=htmlfile, **kwargs)
-            self.htmlfiles.append(htmlfile)
-            plt.close(fig)
+        elif (self.outtype == 'hvplot'):
+            import os
+            import inspect
+            import hvplot
+            import holoviews
+            from bokeh.resources import INLINE
+
+            # html directory in same directory as output file
+            ibase = os.path.dirname(self.plotfile)
+            if not ibase:
+                ibase = './'
+            else:
+                ibase += '/'
+
+            # make holoviews panel or layout
+            if 'ncol' in kwargs:
+                icol = kwargs['ncol']
+            else:
+                icol = self.ncol
+
+            # all holoviews charts + layout
+            hlist = [ hh[1]
+                      for hh in inspect.getmembers(holoviews.element.chart)
+                      if inspect.isclass(hh[1]) ]
+            hlist.append(holoviews.core.layout.Layout)
+            # make holoviews layout if several panels
+            if isinstance(fig, (list, tuple)):
+                layout = fig[0]
+                for pp in fig[1:]:
+                    layout = layout + pp
+            elif isinstance(layout, hlist):
+                layout = fig
+            else:
+                raise ValueError('figure for hvplot must be list/tuple of'
+                                 ' panels, or a holoviews chart or layout.'
+                                 ' Given: ' + type(fig))
+            if isinstance(layout, holoviews.core.layout.Layout):
+                layout = layout.cols(icol)
+
+            # write htmls, menu and plots
+            ff = os.path.basename(filebase(self.plotfile))
+            # name in side panel
+            ffig = f'fig_{self.ifig:04d}'
+            # filename in html/
+            html = f'{ff}_{ffig}.html'
+            # filename in .
+            hhtml = ibase + 'html/' + html
+            print(f'        <p><a href="{html}" target="dynamic">'
+                  f'{ffig}</a>', file=self.fhtml)
+            hvplot.save(layout, hhtml, resources=INLINE)
 
     # -------------------------------------------------------------------------
     # plot end
@@ -981,23 +1096,11 @@ class mcPlot(object):
             self.pdf_pages.close()
         elif (self.outtype == 'png'):
             pass
-        elif (self.outtype == 'html') or (self.outtype == 'd3'):
-            print("</body>\n</html>", file=self.fhtml)
+        elif ( (self.outtype == 'html') or (self.outtype == 'd3') or
+               (self.outtype == 'hvplot') ):
+            print('    </body>', file=self.fhtml)
+            print('</html>', file=self.fhtml)
             self.fhtml.close()
-        elif (self.outtype == 'plotly'):
-            import os
-            if self.ifig > 1:
-                import fileinput
-                htmlfile = self.plotfile
-                with open(htmlfile, 'w') as fout:
-                    fin = fileinput.input(self.htmlfiles)
-                    for line in fin:
-                        fout.write(line)
-                    fin.close()
-                for ff in self.htmlfiles:
-                    os.remove(ff)
-            else:
-                os.rename(self.htmlfiles[0], self.plotfile)
         else:
             import matplotlib.pyplot as plt
             plt.show()
@@ -1018,6 +1121,72 @@ class mcPlot(object):
         """Alias for plot_end()"""
         self.plot_end()
 
+    # -------------------------------------------------------------------------
+    # print layout options
+    #
+    def print_layout_options(self, rcparams=False):
+        """
+        Print the current layout options
+
+        Examples
+        --------
+        Setting layout options in initialisation
+
+        .. code-block:: python
+
+           pp = pyjams.mcPlot()
+           pp.print_layout_options(rcparams=True)
+
+        """
+        import matplotlib as mpl
+        print('Current mcPlot layout options')
+        opts = {'self.nrow': self.nrow, 'self.ncol': self.ncol,
+                'self.left': self.left, 'self.right': self.right,
+                'self.bottom': self.bottom, 'self.top': self.top,
+                'self.hspace': self.hspace, 'self.vspace': self.vspace,
+                'self.textsize': self.textsize,
+                'self.dxabc': self.dxabc, 'self.dyabc': self.dyabc,
+                'self.lwidth': self.lwidth, 'self.elwidth': self.elwidth,
+                'self.alwidth': self.alwidth, 'self.msize': self.msize,
+                'self.mwidth': self.mwidth,
+                'self.dowhite': self.dowhite, 'self.fgcolor': self.fgcolor,
+                'self.bgcolor': self.bgcolor, 'self.mcols': self.mcols,
+                'self.mcol1': self.mcol1, 'self.mcol2': self.mcol2,
+                'self.mcol3': self.mcol3, 'self.mcol4': self.mcol4,
+                'self.mcol5': self.mcol5, 'self.lcol1': self.lcol1,
+                'self.lcol2': self.lcol2, 'self.lcol3': self.lcol3,
+                'self.lcol4': self.lcol4, 'self.lcol5': self.lcol5,
+                'self.lcols': self.lcols, 'self.ldashes': self.ldashes,
+                'self.llxbbox': self.llxbbox,
+                'self.llybbox': self.llybbox, 'self.llrspace': self.llrspace,
+                'self.llcspace': self.llcspace,
+                'self.llhtextpad': self.llhtextpad,
+                'self.llhlength': self.llhlength,
+                'self.frameon': self.frameon,
+                'self.bbox_inches': self.bbox_inches,
+                'self.pad_inches': self.pad_inches,
+                'self.dpi': self.dpi,
+                'self.transparent': self.transparent,
+                'self.serif': self.serif,
+                'self.usetex': self.usetex}
+        kk = sorted(opts.keys())
+        for k in kk:
+            print(f'{k} = {opts[k]}')
+
+        if rcparams:
+            print('')
+            print('matplotlib.rcParams')
+            cat = sorted(set([ k.split('.')[0] for k in mpl.rcParams]))
+            for c in cat:
+                print(f'{c}')
+                for k in mpl.rcParams:
+                    if k.startswith(c):
+                        if '.' in k:
+                            koc = k.removeprefix(f'{c}.')
+                        else:
+                            koc = k
+                        print(f'    {koc} = {mpl.rcParams[k]}')
+
 
 if __name__ == '__main__':
     import doctest
