@@ -7,7 +7,7 @@ This module was written by Matthias Cuntz while at Institut National de
 Recherche pour l'Agriculture, l'Alimentation et l'Environnement (INRAE), Nancy,
 France.
 
-It borrows the idea of _get_variable_definition from the netcdf4 thin layer of
+It borrows the idea of get_variable_definition from the netcdf4 thin layer of
 David Schaefer.
 
 :copyright: Copyright 2020-2022 Matthias Cuntz, see AUTHORS.rst for details.
@@ -25,6 +25,7 @@ The following functions are provided
    create_new_variable
    create_variables
    get_fill_value_for_dtype
+   get_variable_definition
    set_output_filename
 
 History
@@ -39,15 +40,24 @@ History
     * Add copy_variables, May 2022, Matthias Cuntz
     * Delete unnecessary HDF5 filters in variable definition for compatibility
       with netcdf4 > 1.6.0, Jun 2022, Matthias Cuntz
+    * Make get_variable_definition public, Apr 2023, Matthias Cuntz
+    * get_variable_definition returns _FillValue and only then missing_value,
+      Jul 2023, Matthias Cuntz
+    * create_variables sets missing_value attribute if present even if used for
+      _FillValue, Jul 2023, Matthias Cuntz
+    * addglobalatt in copy_file, Dec 2023, Matthias Cuntz
 
 """
 import numpy as np
 import netCDF4 as nc
+from warnings import warn, filterwarnings
+filterwarnings("default", category=DeprecationWarning)
 
 
 __all__ = ['copy_dimensions', 'copy_file', 'copy_global_attributes',
            'copy_variables', 'create_new_variable', 'create_variables',
-           'get_fill_value_for_dtype', 'set_output_filename']
+           'get_fill_value_for_dtype', 'get_variable_definition',
+           'set_output_filename']
 
 
 def _tolist(arg):
@@ -82,7 +92,7 @@ def _tolist(arg):
         return [arg]
 
 
-def _get_variable_definition(ncvar):
+def get_variable_definition(ncvar):
     """
     Collect information on input variable.
 
@@ -102,7 +112,7 @@ def _get_variable_definition(ncvar):
     --------
     .. code-block:: python
 
-       _get_variable_definition(fi.variables['GPP'])
+       get_variable_definition(fi.variables['GPP'])
 
     """
     out = ncvar.filters() if ncvar.filters() else {}
@@ -121,16 +131,16 @@ def _get_variable_definition(ncvar):
             if not isinstance(ncvar.chunking(), str):
                 chunks = list(ncvar.chunking())
     # missing value
-    if "missing_value" in dir(ncvar):
-        ifill = ncvar.missing_value
-    elif "_FillValue" in dir(ncvar):
+    if "_FillValue" in dir(ncvar):
         ifill = ncvar._FillValue
+    elif "missing_value" in dir(ncvar):
+        ifill = ncvar.missing_value
     else:
         ifill = None
     # output variable
     out.update({
-        "name":       ncvar.name,
-        "dtype":      ncvar.dtype,
+        "name": ncvar.name,
+        "dtype": ncvar.dtype,
         "dimensions": list(ncvar.dimensions),
         "fill_value": ifill,
         "chunksizes": chunks,
@@ -140,6 +150,7 @@ def _get_variable_definition(ncvar):
 
 def copy_file(ifile, ofile, timedim='time',
               removevar=[], renamevar={}, replacevar={}, replaceatt={},
+              addglobalatt={},
               noclose=False):
     """
     Copy variables from input file into output file.
@@ -169,6 +180,10 @@ def copy_file(ifile, ofile, timedim='time',
         (case sensitive). Dictionary values are also dictionaries with
         {'attribute_name': attribute_value}. Dictionary keys are the names
         of the output variables after renaming and replacing.
+    addglobalatt : dict, optional
+        Create or add to global file attributes.
+        dict values will be given to attributes given in dict keys.
+        Attributes will be created if they do not exist yet.
     noclose : bool, optional
         Return file handle of opened output file for further manipulation
         if True (default: False)
@@ -192,6 +207,10 @@ def copy_file(ifile, ofile, timedim='time',
 
     """
     import time as ptime
+    warn('The netcdf functions of pyjams were transferred to a standalone'
+         ' repository "ncio". ncio is hence deprecated in pyjams.',
+         category=DeprecationWarning)
+
     fi = nc.Dataset(ifile, 'r')
     if 'file_format' in dir(fi):
         fo = nc.Dataset(ofile, 'w', format=fi.file_format)
@@ -199,9 +218,10 @@ def copy_file(ifile, ofile, timedim='time',
         fo = nc.Dataset(ofile, 'w', format='NETCDF4')
 
     # meta data
-    copy_global_attributes(
-        fi, fo, add={'history': ptime.asctime() + ': ' +
-                     'copy_variables(' + ifile + ', ' + ofile + ')'})
+    if 'history' not in addglobalatt:
+        addglobalatt.update({'history': ptime.asctime() + ': ' +
+                             'copy_variables(' + ifile + ', ' + ofile + ')'})
+    copy_global_attributes(fi, fo, add=addglobalatt)
 
     # copy dimensions
     copy_dimensions(fi, fo)
@@ -295,6 +315,10 @@ def copy_dimensions(fi, fo, removedim=[], renamedim={}, changedim={},
                        changedim={'mland': 1})
 
     """
+    warn('The netcdf functions of pyjams were transferred to a standalone'
+         ' repository "ncio". ncio is hence deprecated in pyjams.',
+         category=DeprecationWarning)
+
     removedim = _tolist(removedim)
     for d in fi.dimensions.values():
         # remove dimension if in removedim
@@ -349,12 +373,16 @@ def copy_global_attributes(fi, fo, add={}, remove=[]):
            fi, fo, add={'history': time.asctime()+': '+' '.join(sys.argv)})
 
     """
+    warn('The netcdf functions of pyjams were transferred to a standalone'
+         ' repository "ncio". ncio is hence deprecated in pyjams.',
+         category=DeprecationWarning)
+
     for k in fi.ncattrs():
         if k not in remove:
             iattr = fi.getncattr(k)
             # add to existing global attribute
             if k in add.keys():
-                iattr += '\n'+add[k]
+                iattr += '\n' + add[k]
             fo.setncattr(k, iattr)
     # add if global attribute does not exist yet
     for k in add.keys():
@@ -401,6 +429,10 @@ def copy_variables(fi, fo, time=None, timedim='time',
        copy_variable(fi, fo, fill=True, renamevar={'lon': 'longitude'})
 
     """
+    warn('The netcdf functions of pyjams were transferred to a standalone'
+         ' repository "ncio". ncio is hence deprecated in pyjams.',
+         category=DeprecationWarning)
+
     removevar = _tolist(removevar)
     # just copy all variables if no time dimension or
     # time dimension not known
@@ -498,6 +530,10 @@ def create_new_variable(invardef, fo, izip=False, fill=None,
        ovar = create_new_variable(nvar, fo, fill=True, izip=True)
 
     """
+    warn('The netcdf functions of pyjams were transferred to a standalone'
+         ' repository "ncio". ncio is hence deprecated in pyjams.',
+         category=DeprecationWarning)
+
     assert 'name' in invardef, 'name not in input dictionary'
     assert 'dtype' in invardef, 'dtype not in input dictionary'
     varname  = invardef.pop("name")
@@ -516,7 +552,7 @@ def create_new_variable(invardef, fo, izip=False, fill=None,
             _ = ncdict.pop('chunksizes')
     if 'fill_value' not in ncdict:
         ncdict.update({'fill_value': None})
-    # set missing value if None
+    # set _FillValue if None
     if ncdict['fill_value'] is None:
         if fill:
             if isinstance(fill, bool):
@@ -602,6 +638,10 @@ def create_variables(fi, fo, time=None, timedim='time', izip=False, fill=None,
                        replacedim={'land': ('y', 'x')})
 
     """
+    warn('The netcdf functions of pyjams were transferred to a standalone'
+         ' repository "ncio". ncio is hence deprecated in pyjams.',
+         category=DeprecationWarning)
+
     removevar = _tolist(removevar)
     removedim = _tolist(removedim)
     for ivar in fi.variables.values():
@@ -615,7 +655,7 @@ def create_variables(fi, fo, time=None, timedim='time', izip=False, fill=None,
                 else:
                     itime = timedim not in ivar.dimensions
             if itime:
-                invardef = _get_variable_definition(ivar)
+                invardef = get_variable_definition(ivar)
                 if izip:
                     invardef.update({'zlib': True})
                 # rename variable if in renamevar
@@ -639,17 +679,17 @@ def create_variables(fi, fo, time=None, timedim='time', izip=False, fill=None,
                     if dd in dims:
                         rdim = _tolist(replacedim[dd])
                         ip = dims.index(dd)
-                        dims = dims[:ip] + rdim + dims[ip+1:]
+                        dims = dims[:ip] + rdim + dims[ip + 1:]
                         if chunks:
                             rchunk = []
                             for cc in rdim:
                                 # use fo not fi because new dims perhaps
                                 # not yet in fi
                                 rchunk.append(len(fo.dimensions[cc]))
-                            chunks = chunks[:ip] + rchunk + chunks[ip+1:]
+                            chunks = chunks[:ip] + rchunk + chunks[ip + 1:]
                 invardef['dimensions'] = dims
                 invardef['chunksizes'] = chunks
-                # set missing value if None
+                # set _FillValue if None
                 if invardef['fill_value'] is None:
                     if fill:
                         if isinstance(fill, bool):
@@ -665,7 +705,7 @@ def create_variables(fi, fo, time=None, timedim='time', izip=False, fill=None,
                 ovar = fo.createVariable(oname, otype, **invardef)
                 for k in ivar.ncattrs():
                     iattr = ivar.getncattr(k)
-                    if (k != 'missing_value') and (k != '_FillValue'):
+                    if k != '_FillValue':
                         ovar.setncattr(k, iattr)
     return
 
@@ -712,7 +752,7 @@ def get_fill_value_for_dtype(dtype):
         return nc.default_fillvals['f8']
     else:
         import warnings
-        warnings.warn("data type unknown: "+str(dtype))
+        warnings.warn("data type unknown: " + str(dtype))
         return None
 
 
@@ -742,7 +782,7 @@ def set_output_filename(ifile, ext):
 
     """
     sifile = ifile.split('.')
-    sifile[-2] = sifile[-2]+ext
+    sifile[-2] = sifile[-2] + ext
     ofile = '.'.join(sifile)
     return ofile
 
