@@ -51,13 +51,16 @@ History
     * Use text2plot for signature2plot, Nov 2021, Matthias Cuntz
     * Use text2plot for abc2plot, Nov 2021, Matthias Cuntz
     * More consistent docstrings, Jan 2022, Matthias Cuntz
+    * Added upper keyword in abc2plot, Jun 2024, Matthias Cuntz
 
 """
 import time as ptime
-# from .str2tex import str2tex
-# from .romanliterals import int2roman
-from pyjams.str2tex import str2tex
-from pyjams.romanliterals import int2roman
+from .str2tex import str2tex
+from .romanliterals import int2roman
+# from pyjams.str2tex import str2tex
+# from pyjams.romanliterals import int2roman
+from warnings import warn, filterwarnings
+filterwarnings("default", category=DeprecationWarning)
 
 
 __all__ = ['text2plot', 'abc2plot', 'signature2plot']
@@ -128,6 +131,10 @@ def text2plot(handle, dx, dy, itext,
 
     """
     import matplotlib.pyplot as plt
+    warn('The plotting functions of pyjams were transferred to a'
+         ' standalone repository "mcplot". text2plot is hence deprecated'
+         ' in pyjams.',
+         category=DeprecationWarning)
 
     # Check input
     ifont = small + medium + large + xsmall + xxsmall + xlarge + xxlarge
@@ -197,7 +204,7 @@ def text2plot(handle, dx, dy, itext,
 
 
 def abc2plot(handle, dx, dy, iplot,
-             integer=False, roman=False, lower=False,
+             integer=False, roman=False, lower=False, upper=None,
              parentheses=None, brackets=None, braces=None,
              bold=False, italic=False,
              usetex=False, mathrm=False, string=False,
@@ -221,7 +228,12 @@ def abc2plot(handle, dx, dy, iplot,
         Use Roman literals instead of a, b, c if True (default: False)
     lower : bool, optional
         Use lowercase letters for a, b, c if True,
-        else use uppercase letters (default)
+        else use uppercase letters (default).
+        lower=True and upper=True are mutually exclusive.
+    upper : bool, optional
+        Use uppercase letters for A, B, C if True (default),
+        else use lowercase letters.
+        lower=True and upper=True are mutually exclusive.
     parentheses : str or None, optional
         Parentheses before or after the letter/number. Possible values are
         'open', 'close', 'both', 'None', and *None*.
@@ -282,8 +294,8 @@ def abc2plot(handle, dx, dy, iplot,
     import matplotlib.pyplot as plt
 
     # Check input
-    assert (roman + integer) < 2, ('either Roman literals or integers can'
-                                   ' be chosen.')
+    assert not (roman and integer), (
+        'either Roman literals or integers can be chosen.')
     iparentheses = False
     if parentheses is not None:
         if parentheses != 'None':
@@ -299,6 +311,14 @@ def abc2plot(handle, dx, dy, iplot,
     ibrack = iparentheses + ibrackets + ibraces
     assert ibrack <= 1, ('only one of parentheses, brackets, or braces'
                          ' can be chosen.')
+    if upper is not None:
+        assert not (upper and lower), (
+            'either uppercase or lowercase can be chosen.')
+        # assure correct lower keyword if upper=False given
+        if upper:
+            lower = False
+        else:
+            lower = True
 
     # Number or letter
     if string:
@@ -310,9 +330,9 @@ def abc2plot(handle, dx, dy, iplot,
             t = str(iplot)
         else:
             if lower:
-                t = chr(96+iplot)
+                t = chr(96 + iplot)
             else:
-                t = chr(64+iplot)
+                t = chr(64 + iplot)
 
     # parentheses
     if iparentheses:
