@@ -19,151 +19,191 @@ class TestDate2Date(unittest.TestCase):
         from pyjams import date2date
 
         edate = ['2014-11-12 12:00', '01.03.2015T17:56:00',
-                 '12/01/1990', '04.05.1786']
+                 '12/01/1990', '04.05.1786',
+                 '-2014-11-12 12:00', '01.03.2015T17:56:00.5',
+                 '12.11.-2014 12:00']
+        asdate = ['12.11.2014 12:00', '01.03.2015 17:56:00',
+                  '01.12.1990', '04.05.1786',
+                  '12.11.-2014 12:00', '01.03.2015 17:56:00.5',
+                  '12.11.-2014 12:00']
+        endate = ['2014-11-12 12:00', '2015-03-01 17:56:00',
+                  '1990-12-01', '1786-05-04',
+                  '-2014-11-12 12:00', '2015-03-01 17:56:00.5',
+                  '-2014-11-12 12:00']
+        usdate = ['11/12/2014 12:00', '03/01/2015 17:56:00',
+                  '12/01/1990', '05/04/1786',
+                  '11/12/-2014 12:00', '03/01/2015 17:56:00.5',
+                  '11/12/-2014 12:00']
+        frdate = ['12/11/2014 12:00', '01/03/2015 17:56:00',
+                  '01/12/1990', '04/05/1786',
+                  '12/11/-2014 12:00', '01/03/2015 17:56:00.5',
+                  '12/11/-2014 12:00']
+        asdatefull = ['12.11.2014 12:00:00', '01.03.2015 17:56:00',
+                      '01.12.1990 00:00:00', '04.05.1786 00:00:00',
+                      '12.11.-2014 12:00:00', '01.03.2015 17:56:00.5',
+                      '12.11.-2014 12:00:00']
+        endatefull = ['2014-11-12 12:00:00', '2015-03-01 17:56:00',
+                      '1990-12-01 00:00:00', '1786-05-04 00:00:00',
+                      '-2014-11-12 12:00:00', '2015-03-01 17:56:00.5',
+                      '-2014-11-12 12:00:00']
+        usdatefull = ['11/12/2014 12:00:00', '03/01/2015 17:56:00',
+                      '12/01/1990 00:00:00', '05/04/1786 00:00:00',
+                      '11/12/-2014 12:00:00', '03/01/2015 17:56:00.5',
+                      '11/12/-2014 12:00:00']
+        frdatefull = ['12/11/2014 12:00:00', '01/03/2015 17:56:00',
+                      '01/12/1990 00:00:00', '04/05/1786 00:00:00',
+                      '12/11/-2014 12:00:00', '01/03/2015 17:56:00.5',
+                      '12/11/-2014 12:00:00']
+        icosdate = ['20141112120000', '20150301175600',
+                    '19901201000000', '17860504000000',
+                    '-20141112120000', '20150301175600.5',
+                    '-20141112120000']
 
-        out  = date2date(edate)
+        out = date2date(edate)
         assert isinstance(out, list)
-        soll = ['12.11.2014 12:00', '01.03.2015 17:56:00', '01.12.1990',
-                '04.05.1786']
+        soll = asdate
         self.assertEqual(soll, out)
 
-        out  = date2date(edate, full=True)
+        out = date2date(edate, full=True)
         assert isinstance(out, list)
-        soll = ['12.11.2014 12:00:00', '01.03.2015 17:56:00',
-                '01.12.1990 00:00:00', '04.05.1786 00:00:00']
+        soll = asdatefull
         self.assertEqual(soll, out)
 
-        out  = date2date(edate, format='en')
+        out = date2date(edate, format='en')
         assert isinstance(out, list)
-        soll = ['2014-11-12 12:00', '2015-03-01 17:56:00', '1990-12-01',
-                '1786-05-04']
+        soll = endate
         self.assertEqual(soll, out)
 
-        out  = date2date(edate, format='en', full=True)
+        out = date2date(edate, format='en', full=True)
         assert isinstance(out, list)
-        soll = ['2014-11-12 12:00:00', '2015-03-01 17:56:00',
-                '1990-12-01 00:00:00', '1786-05-04 00:00:00']
+        soll = endatefull
         self.assertEqual(soll, out)
 
-        out  = date2date(edate, format='en', full=True, timesep='T')
+        out = date2date(edate, format='en', full=True, timesep='T')
         assert isinstance(out, list)
-        soll = ['2014-11-12T12:00:00', '2015-03-01T17:56:00',
-                '1990-12-01T00:00:00', '1786-05-04T00:00:00']
+        soll = [ dt.replace(' ', 'T') for dt in endatefull ]
         self.assertEqual(soll, out)
 
-        out  = date2date(edate, format='%Y%m%d%H%M%S', full=True, timesep='T')
+        # out = date2date(edate, format='%Y%m%d%H%M%S', full=True, timesep='T')
+        # assert isinstance(out, list)
+        # soll = icosdate
+        # self.assertEqual(soll, out)
+
+        out = date2date(list(edate))
         assert isinstance(out, list)
-        soll = ['20141112120000', '20150301175600',
-                '19901201000000', '17860504000000']
+        soll = asdate
         self.assertEqual(soll, out)
 
-        out  = date2date(list(edate))
-        assert isinstance(out, list)
-        soll = ['12.11.2014 12:00', '01.03.2015 17:56:00', '01.12.1990',
-                '04.05.1786']
-        self.assertEqual(soll, out)
-
-        out  = date2date(tuple(edate))
+        out = date2date(tuple(edate))
         assert isinstance(out, tuple)
-        soll = ('12.11.2014 12:00', '01.03.2015 17:56:00', '01.12.1990',
-                '04.05.1786')
+        soll = asdate
         self.assertEqual(list(soll), list(out))
 
-        out  = date2date(np.array(edate))
+        out = date2date(np.array(edate))
         assert isinstance(out, np.ndarray)
-        soll = ['12.11.2014 12:00', '01.03.2015 17:56:00', '01.12.1990',
-                '04.05.1786']
-        self.assertEqual(soll, list(out))
+        soll = asdate
+        self.assertEqual(list(soll), list(out))
 
-        out  = date2date(edate[0])
+        out = date2date(edate[0])
         assert isinstance(out, str)
-        soll = '12.11.2014 12:00'
+        soll = asdate[0]
         assert soll == out
 
-        out  = date2date(edate, format='us')
+        out = date2date(edate, format='us')
         assert isinstance(out, list)
-        soll = ['11/12/2014 12:00', '03/01/2015 17:56:00', '12/01/1990',
-                '05/04/1786']
+        soll = usdate
         self.assertEqual(soll, out)
 
-        out  = date2date(edate, format='us', full=True)
+        out = date2date(edate, format='us', full=True)
         assert isinstance(out, list)
-        soll = ['11/12/2014 12:00:00', '03/01/2015 17:56:00',
-                '12/01/1990 00:00:00', '05/04/1786 00:00:00']
+        soll = usdatefull
         self.assertEqual(soll, out)
 
-        out  = date2date(edate, format='fr')
+        out = date2date(edate, format='fr')
         assert isinstance(out, list)
-        soll = ['12/11/2014 12:00', '01/03/2015 17:56:00', '01/12/1990',
-                '04/05/1786']
+        soll = frdate
         self.assertEqual(soll, out)
 
-        out  = date2date(edate, format='fr', full=True)
+        out = date2date(edate, format='fr', full=True)
         assert isinstance(out, list)
-        soll = ['12/11/2014 12:00:00', '01/03/2015 17:56:00',
-                '01/12/1990 00:00:00', '04/05/1786 00:00:00']
+        soll = frdatefull
         self.assertEqual(soll, out)
 
         # fr
-        edate = ['2014-11-12 12:00', '01.03.2015T17:56:00',
-                 '01/12/1990', '04.05.1786']
+        edate = ['2014-11-12 12:00', '01.03.2015 17:56:00',
+                 '01/12/1990', '04.05.1786',
+                 '12/11/-2014 12:00', '01.03.2015 17:56:00.5']
+        asdate = ['12.11.2014 12:00', '01.03.2015 17:56:00',
+                  '01.12.1990', '04.05.1786',
+                  '12.11.-2014 12:00', '01.03.2015 17:56:00.5']
+        asdatefull = ['12.11.2014 12:00:00', '01.03.2015 17:56:00',
+                      '01.12.1990 00:00:00', '04.05.1786 00:00:00',
+                      '12.11.-2014 12:00:00', '01.03.2015 17:56:00.5']
 
-        out  = date2date(edate, fr=True)
+        out = date2date(edate, fr=True)
         assert isinstance(out, list)
-        soll = ['12.11.2014 12:00', '01.03.2015 17:56:00', '01.12.1990',
-                '04.05.1786']
+        soll = asdate
         self.assertEqual(soll, out)
 
-        out  = date2date(edate, fr=True, full=True)
+        out = date2date(edate, fr=True, full=True)
         assert isinstance(out, list)
-        soll = ['12.11.2014 12:00:00', '01.03.2015 17:56:00',
-                '01.12.1990 00:00:00', '04.05.1786 00:00:00']
+        soll = asdatefull
         self.assertEqual(soll, out)
 
         # 1-2 digits
         edate = ['1-11-12 12:00', '1.3.15 17:56:00', '90-12-1']
+        asdate = ['12.11.2001 12:00', '01.03.2015 17:56:00',
+                  '01.12.1990']
+        endate = ['2001-11-12 12:00', '2015-03-01 17:56:00',
+                  '1990-12-01']
+        usdate = ['11/12/2001 12:00', '03/01/2015 17:56:00',
+                  '12/01/1990']
+        usdatefull = ['11/12/2001 12:00:00', '03/01/2015 17:56:00',
+                      '12/01/1990 00:00:00']
+        frdatefull = ['12/11/2001 12:00:00', '01/03/2015 17:56:00',
+                      '01/12/1990 00:00:00']
 
-        out  = date2date(edate)
+        out = date2date(edate)
         assert isinstance(out, list)
-        soll = ['12.11.2001 12:00', '01.03.2015 17:56:00', '01.12.1990']
+        soll = asdate
         self.assertEqual(soll, out)
 
-        out  = date2date(edate, format='en')
+        out = date2date(edate, format='en')
         assert isinstance(out, list)
-        soll = ['2001-11-12 12:00', '2015-03-01 17:56:00', '1990-12-01']
+        soll = endate
         self.assertEqual(soll, out)
 
-        out  = date2date(edate, format='us')
+        out = date2date(edate, format='us')
         assert isinstance(out, list)
-        soll = ['11/12/2001 12:00', '03/01/2015 17:56:00', '12/01/1990']
+        soll = usdate
         self.assertEqual(soll, out)
 
-        out  = date2date(edate, format='us', full=True)
+        out = date2date(edate, format='us', full=True)
         assert isinstance(out, list)
-        soll = ['11/12/2001 12:00:00', '03/01/2015 17:56:00',
-                '12/01/1990 00:00:00']
+        soll = usdatefull
         self.assertEqual(soll, out)
 
-        out  = date2date(edate, format='fr', full=True)
+        out = date2date(edate, format='fr', full=True)
         assert isinstance(out, list)
-        soll = ['12/11/2001 12:00:00', '01/03/2015 17:56:00',
-                '01/12/1990 00:00:00']
+        soll = frdatefull
         self.assertEqual(soll, out)
 
         # times
         edate = ['2014-11-12 12:00', '01.03.2015 17:56:00',
                  '1990-12-01 01', '04.05.1786']
+        asdate = ['12.11.2014 12:00', '01.03.2015 17:56:00',
+                  '01.12.1990 01', '04.05.1786']
+        asdatefull = ['12.11.2014 12:00:00', '01.03.2015 17:56:00',
+                      '01.12.1990 01:00:00', '04.05.1786 00:00:00']
 
-        out  = date2date(edate)
+        out = date2date(edate)
         assert isinstance(out, list)
-        soll = ['12.11.2014 12:00', '01.03.2015 17:56:00', '01.12.1990 01',
-                '04.05.1786']
+        soll = asdate
         self.assertEqual(soll, out)
 
-        out  = date2date(edate, full=True)
+        out = date2date(edate, full=True)
         assert isinstance(out, list)
-        soll = ['12.11.2014 12:00:00', '01.03.2015 17:56:00',
-                '01.12.1990 01:00:00', '04.05.1786 00:00:00']
+        soll = asdatefull
         self.assertEqual(soll, out)
 
         # errors
@@ -178,6 +218,10 @@ class TestDate2Date(unittest.TestCase):
         # 3-digit year
         edate = ['1-11-12 12:00', '1.3.15 17:56:00', '190-12-1']
         self.assertRaises(ValueError, date2date, edate)
+        # wrong negative date
+        edate = ['-2014-11-12 12:00', '01.03.-2015 17:56:00',
+                 '01--1990-12 01', '04.05.1786', '01-12-1990-']
+        self.assertRaises(ValueError, date2date, edate)
 
     def test_date2en(self):
         from pyjams import date2en
@@ -185,19 +229,19 @@ class TestDate2Date(unittest.TestCase):
         edate = ['2014-11-12 12:00', '01.03.2015 17:56:00',
                  '1990-12-01', '04.05.1786']
 
-        out  = date2en(edate)
+        out = date2en(edate)
         assert isinstance(out, list)
         soll = ['2014-11-12 12:00', '2015-03-01 17:56:00', '1990-12-01',
                 '1786-05-04']
         self.assertEqual(soll, out)
 
-        out  = date2en(edate, full=True)
+        out = date2en(edate, full=True)
         assert isinstance(out, list)
         soll = ['2014-11-12 12:00:00', '2015-03-01 17:56:00',
                 '1990-12-01 00:00:00', '1786-05-04 00:00:00']
         self.assertEqual(soll, out)
 
-        out  = date2en(edate, format='%Y%m%d%H%M%S', full=True, timesep='T')
+        out = date2en(edate, format='%Y%m%d%H%M%S', full=True, timesep='T')
         assert isinstance(out, list)
         soll = ['20141112120000', '20150301175600',
                 '19901201000000', '17860504000000']
@@ -205,7 +249,7 @@ class TestDate2Date(unittest.TestCase):
 
         edate = ['1-11-12 12:00', '1.3.15 17:56:00', '90-12-1']
 
-        out  = date2en(edate, full=True)
+        out = date2en(edate, full=True)
         assert isinstance(out, list)
         soll = ['2001-11-12 12:00:00', '2015-03-01 17:56:00',
                 '1990-12-01 00:00:00']
@@ -217,19 +261,19 @@ class TestDate2Date(unittest.TestCase):
         edate = ['2014-11-12 12:00', '01.03.2015 17:56:00',
                  '1990-12-01', '04.05.1786']
 
-        out  = date2fr(edate)
+        out = date2fr(edate)
         assert isinstance(out, list)
         soll = ['12/11/2014 12:00', '01/03/2015 17:56:00', '01/12/1990',
                 '04/05/1786']
         self.assertEqual(soll, out)
 
-        out  = date2fr(edate, full=True)
+        out = date2fr(edate, full=True)
         assert isinstance(out, list)
         soll = ['12/11/2014 12:00:00', '01/03/2015 17:56:00',
                 '01/12/1990 00:00:00', '04/05/1786 00:00:00']
         self.assertEqual(soll, out)
 
-        out  = date2fr(edate, format='%Y%m%d%H%M%S', full=True, timesep='T')
+        out = date2fr(edate, format='%Y%m%d%H%M%S', full=True, timesep='T')
         assert isinstance(out, list)
         soll = ['20141112120000', '20150301175600',
                 '19901201000000', '17860504000000']
@@ -237,7 +281,7 @@ class TestDate2Date(unittest.TestCase):
 
         edate = ['1-11-12 12:00', '1.3.15 17:56:00', '90-12-1']
 
-        out  = date2fr(edate, full=True)
+        out = date2fr(edate, full=True)
         assert isinstance(out, list)
         soll = ['12/11/2001 12:00:00', '01/03/2015 17:56:00',
                 '01/12/1990 00:00:00']
@@ -249,19 +293,19 @@ class TestDate2Date(unittest.TestCase):
         edate = ['2014-11-12 12:00', '01.03.2015 17:56:00',
                  '1990-12-01', '04.05.1786']
 
-        out  = date2us(edate)
+        out = date2us(edate)
         assert isinstance(out, list)
         soll = ['11/12/2014 12:00', '03/01/2015 17:56:00', '12/01/1990',
                 '05/04/1786']
         self.assertEqual(soll, out)
 
-        out  = date2us(edate, full=True)
+        out = date2us(edate, full=True)
         assert isinstance(out, list)
         soll = ['11/12/2014 12:00:00', '03/01/2015 17:56:00',
                 '12/01/1990 00:00:00', '05/04/1786 00:00:00']
         self.assertEqual(soll, out)
 
-        out  = date2us(edate, format='%Y%m%d%H%M%S', full=True, timesep='T')
+        out = date2us(edate, format='%Y%m%d%H%M%S', full=True, timesep='T')
         assert isinstance(out, list)
         soll = ['20141112120000', '20150301175600',
                 '19901201000000', '17860504000000']
@@ -269,7 +313,7 @@ class TestDate2Date(unittest.TestCase):
 
         edate = ['1-11-12 12:00', '1.3.15 17:56:00', '90-12-1']
 
-        out  = date2us(edate, full=True)
+        out = date2us(edate, full=True)
         assert isinstance(out, list)
         soll = ['11/12/2001 12:00:00', '03/01/2015 17:56:00',
                 '12/01/1990 00:00:00']
@@ -281,19 +325,19 @@ class TestDate2Date(unittest.TestCase):
         edate = ['2014-11-12 12:00', '01.03.2015 17:56:00',
                  '1990-12-01', '04.05.1786']
 
-        out  = en2date(edate)
+        out = en2date(edate)
         assert isinstance(out, list)
         soll = ['12.11.2014 12:00', '01.03.2015 17:56:00', '01.12.1990',
                 '04.05.1786']
         self.assertEqual(soll, out)
 
-        out  = en2date(edate, full=True)
+        out = en2date(edate, full=True)
         assert isinstance(out, list)
         soll = ['12.11.2014 12:00:00', '01.03.2015 17:56:00',
                 '01.12.1990 00:00:00', '04.05.1786 00:00:00']
         self.assertEqual(soll, out)
 
-        out  = en2date(edate, format='%Y%m%d%H%M%S', full=True, timesep='T')
+        out = en2date(edate, format='%Y%m%d%H%M%S', full=True, timesep='T')
         assert isinstance(out, list)
         soll = ['20141112120000', '20150301175600',
                 '19901201000000', '17860504000000']
@@ -301,7 +345,7 @@ class TestDate2Date(unittest.TestCase):
 
         edate = ['1-11-12 12:00', '1.3.15 17:56:00', '90-12-1']
 
-        out  = en2date(edate, full=True)
+        out = en2date(edate, full=True)
         assert isinstance(out, list)
         soll = ['12.11.2001 12:00:00', '01.03.2015 17:56:00',
                 '01.12.1990 00:00:00']
@@ -313,19 +357,19 @@ class TestDate2Date(unittest.TestCase):
         edate = ['2014-11-12 12:00', '01.03.2015 17:56:00',
                  '1990-12-01', '04.05.1786']
 
-        out  = en2fr(edate)
+        out = en2fr(edate)
         assert isinstance(out, list)
         soll = ['12/11/2014 12:00', '01/03/2015 17:56:00', '01/12/1990',
                 '04/05/1786']
         self.assertEqual(soll, out)
 
-        out  = en2fr(edate, full=True)
+        out = en2fr(edate, full=True)
         assert isinstance(out, list)
         soll = ['12/11/2014 12:00:00', '01/03/2015 17:56:00',
                 '01/12/1990 00:00:00', '04/05/1786 00:00:00']
         self.assertEqual(soll, out)
 
-        out  = en2fr(edate, format='%Y%m%d%H%M%S', full=True, timesep='T')
+        out = en2fr(edate, format='%Y%m%d%H%M%S', full=True, timesep='T')
         assert isinstance(out, list)
         soll = ['20141112120000', '20150301175600',
                 '19901201000000', '17860504000000']
@@ -333,7 +377,7 @@ class TestDate2Date(unittest.TestCase):
 
         edate = ['1-11-12 12:00', '1.3.15 17:56:00', '90-12-1']
 
-        out  = en2fr(edate, full=True)
+        out = en2fr(edate, full=True)
         assert isinstance(out, list)
         soll = ['12/11/2001 12:00:00', '01/03/2015 17:56:00',
                 '01/12/1990 00:00:00']
@@ -345,19 +389,19 @@ class TestDate2Date(unittest.TestCase):
         edate = ['2014-11-12 12:00', '01.03.2015 17:56:00',
                  '1990-12-01', '04.05.1786']
 
-        out  = en2us(edate)
+        out = en2us(edate)
         assert isinstance(out, list)
         soll = ['11/12/2014 12:00', '03/01/2015 17:56:00', '12/01/1990',
                 '05/04/1786']
         self.assertEqual(soll, out)
 
-        out  = en2us(edate, full=True)
+        out = en2us(edate, full=True)
         assert isinstance(out, list)
         soll = ['11/12/2014 12:00:00', '03/01/2015 17:56:00',
                 '12/01/1990 00:00:00', '05/04/1786 00:00:00']
         self.assertEqual(soll, out)
 
-        out  = en2us(edate, format='%Y%m%d%H%M%S', full=True, timesep='T')
+        out = en2us(edate, format='%Y%m%d%H%M%S', full=True, timesep='T')
         assert isinstance(out, list)
         soll = ['20141112120000', '20150301175600',
                 '19901201000000', '17860504000000']
@@ -365,7 +409,7 @@ class TestDate2Date(unittest.TestCase):
 
         edate = ['1-11-12 12:00', '1.3.15 17:56:00', '90-12-1']
 
-        out  = en2us(edate, full=True)
+        out = en2us(edate, full=True)
         assert isinstance(out, list)
         soll = ['11/12/2001 12:00:00', '03/01/2015 17:56:00',
                 '12/01/1990 00:00:00']
@@ -377,19 +421,19 @@ class TestDate2Date(unittest.TestCase):
         edate = ['12/11/2014 12:00', '01/03/2015 17:56:00',
                  '01/12/1990', '04/05/1786']
 
-        out  = fr2date(edate)
+        out = fr2date(edate)
         assert isinstance(out, list)
         soll = ['12.11.2014 12:00', '01.03.2015 17:56:00', '01.12.1990',
                 '04.05.1786']
         self.assertEqual(soll, out)
 
-        out  = fr2date(edate, full=True)
+        out = fr2date(edate, full=True)
         assert isinstance(out, list)
         soll = ['12.11.2014 12:00:00', '01.03.2015 17:56:00',
                 '01.12.1990 00:00:00', '04.05.1786 00:00:00']
         self.assertEqual(soll, out)
 
-        out  = fr2date(edate, format='%Y%m%d%H%M%S', full=True, timesep='T')
+        out = fr2date(edate, format='%Y%m%d%H%M%S', full=True, timesep='T')
         assert isinstance(out, list)
         soll = ['20141112120000', '20150301175600',
                 '19901201000000', '17860504000000']
@@ -397,7 +441,7 @@ class TestDate2Date(unittest.TestCase):
 
         edate = ['12/11/1 12:00', '1/3/15 17:56:00', '1/12/90']
 
-        out  = fr2date(edate, full=True)
+        out = fr2date(edate, full=True)
         assert isinstance(out, list)
         soll = ['12.11.2001 12:00:00', '01.03.2015 17:56:00',
                 '01.12.1990 00:00:00']
@@ -409,19 +453,19 @@ class TestDate2Date(unittest.TestCase):
         edate = ['12/11/2014 12:00', '01/03/2015 17:56:00',
                  '01/12/1990', '04/05/1786']
 
-        out  = fr2en(edate)
+        out = fr2en(edate)
         assert isinstance(out, list)
         soll = ['2014-11-12 12:00', '2015-03-01 17:56:00', '1990-12-01',
                 '1786-05-04']
         self.assertEqual(soll, out)
 
-        out  = fr2en(edate, full=True)
+        out = fr2en(edate, full=True)
         assert isinstance(out, list)
         soll = ['2014-11-12 12:00:00', '2015-03-01 17:56:00',
                 '1990-12-01 00:00:00', '1786-05-04 00:00:00']
         self.assertEqual(soll, out)
 
-        out  = fr2en(edate, format='%Y%m%d%H%M%S', full=True, timesep='T')
+        out = fr2en(edate, format='%Y%m%d%H%M%S', full=True, timesep='T')
         assert isinstance(out, list)
         soll = ['20141112120000', '20150301175600',
                 '19901201000000', '17860504000000']
@@ -429,7 +473,7 @@ class TestDate2Date(unittest.TestCase):
 
         edate = ['12/11/1 12:00', '1/3/15 17:56:00', '1/12/90']
 
-        out  = fr2en(edate, full=True)
+        out = fr2en(edate, full=True)
         assert isinstance(out, list)
         soll = ['2001-11-12 12:00:00', '2015-03-01 17:56:00',
                 '1990-12-01 00:00:00']
@@ -441,19 +485,19 @@ class TestDate2Date(unittest.TestCase):
         edate = ['12/11/2014 12:00', '01/03/2015 17:56:00',
                  '01/12/1990', '04/05/1786']
 
-        out  = fr2us(edate)
+        out = fr2us(edate)
         assert isinstance(out, list)
         soll = ['11/12/2014 12:00', '03/01/2015 17:56:00', '12/01/1990',
                 '05/04/1786']
         self.assertEqual(soll, out)
 
-        out  = fr2us(edate, full=True)
+        out = fr2us(edate, full=True)
         assert isinstance(out, list)
         soll = ['11/12/2014 12:00:00', '03/01/2015 17:56:00',
                 '12/01/1990 00:00:00', '05/04/1786 00:00:00']
         self.assertEqual(soll, out)
 
-        out  = fr2us(edate, format='%Y%m%d%H%M%S', full=True, timesep='T')
+        out = fr2us(edate, format='%Y%m%d%H%M%S', full=True, timesep='T')
         assert isinstance(out, list)
         soll = ['20141112120000', '20150301175600',
                 '19901201000000', '17860504000000']
@@ -461,7 +505,7 @@ class TestDate2Date(unittest.TestCase):
 
         edate = ['12/11/1 12:00', '1/3/15 17:56:00', '1/12/90']
 
-        out  = fr2us(edate, full=True)
+        out = fr2us(edate, full=True)
         assert isinstance(out, list)
         soll = ['11/12/2001 12:00:00', '03/01/2015 17:56:00',
                 '12/01/1990 00:00:00']
@@ -473,19 +517,19 @@ class TestDate2Date(unittest.TestCase):
         edate = ['11/12/2014 12:00', '03/01/2015 17:56:00',
                  '1990-12-01', '04.05.1786']
 
-        out  = us2date(edate)
+        out = us2date(edate)
         assert isinstance(out, list)
         soll = ['12.11.2014 12:00', '01.03.2015 17:56:00', '01.12.1990',
                 '04.05.1786']
         self.assertEqual(soll, out)
 
-        out  = us2date(edate, full=True)
+        out = us2date(edate, full=True)
         assert isinstance(out, list)
         soll = ['12.11.2014 12:00:00', '01.03.2015 17:56:00',
                 '01.12.1990 00:00:00', '04.05.1786 00:00:00']
         self.assertEqual(soll, out)
 
-        out  = us2date(edate, format='%Y%m%d%H%M%S', full=True, timesep='T')
+        out = us2date(edate, format='%Y%m%d%H%M%S', full=True, timesep='T')
         assert isinstance(out, list)
         soll = ['20141112120000', '20150301175600',
                 '19901201000000', '17860504000000']
@@ -493,7 +537,7 @@ class TestDate2Date(unittest.TestCase):
 
         edate = ['11/12/1 12:00', '3/1/15 17:56:00', '90-12-1']
 
-        out  = us2date(date2us(edate), full=True)
+        out = us2date(date2us(edate), full=True)
         assert isinstance(out, list)
         soll = ['12.11.2001 12:00:00', '01.03.2015 17:56:00',
                 '01.12.1990 00:00:00']
@@ -505,19 +549,19 @@ class TestDate2Date(unittest.TestCase):
         edate = ['11/12/2014 12:00', '03/01/2015 17:56:00',
                  '1990-12-01', '04.05.1786']
 
-        out  = us2en(edate)
+        out = us2en(edate)
         assert isinstance(out, list)
         soll = ['2014-11-12 12:00', '2015-03-01 17:56:00', '1990-12-01',
                 '1786-05-04']
         self.assertEqual(soll, out)
 
-        out  = us2en(edate, full=True)
+        out = us2en(edate, full=True)
         assert isinstance(out, list)
         soll = ['2014-11-12 12:00:00', '2015-03-01 17:56:00',
                 '1990-12-01 00:00:00', '1786-05-04 00:00:00']
         self.assertEqual(soll, out)
 
-        out  = us2en(edate, format='%Y%m%d%H%M%S', full=True, timesep='T')
+        out = us2en(edate, format='%Y%m%d%H%M%S', full=True, timesep='T')
         assert isinstance(out, list)
         soll = ['20141112120000', '20150301175600',
                 '19901201000000', '17860504000000']
@@ -525,7 +569,7 @@ class TestDate2Date(unittest.TestCase):
 
         edate = ['11/12/1 12:00', '3/1/15 17:56:00', '90-12-1']
 
-        out  = us2en(edate, full=True)
+        out = us2en(edate, full=True)
         assert isinstance(out, list)
         soll = ['2001-11-12 12:00:00', '2015-03-01 17:56:00',
                 '1990-12-01 00:00:00']
@@ -537,19 +581,19 @@ class TestDate2Date(unittest.TestCase):
         edate = ['11/12/2014 12:00', '03/01/2015 17:56:00',
                  '1990-12-01', '04.05.1786']
 
-        out  = us2fr(edate)
+        out = us2fr(edate)
         assert isinstance(out, list)
         soll = ['12/11/2014 12:00', '01/03/2015 17:56:00', '01/12/1990',
                 '04/05/1786']
         self.assertEqual(soll, out)
 
-        out  = us2fr(edate, full=True)
+        out = us2fr(edate, full=True)
         assert isinstance(out, list)
         soll = ['12/11/2014 12:00:00', '01/03/2015 17:56:00',
                 '01/12/1990 00:00:00', '04/05/1786 00:00:00']
         self.assertEqual(soll, out)
 
-        out  = us2fr(edate, format='%Y%m%d%H%M%S', full=True, timesep='T')
+        out = us2fr(edate, format='%Y%m%d%H%M%S', full=True, timesep='T')
         assert isinstance(out, list)
         soll = ['20141112120000', '20150301175600',
                 '19901201000000', '17860504000000']
@@ -557,7 +601,7 @@ class TestDate2Date(unittest.TestCase):
 
         edate = ['11/12/1 12:00', '3/1/15 17:56:00', '90-12-1']
 
-        out  = us2fr(edate, full=True)
+        out = us2fr(edate, full=True)
         assert isinstance(out, list)
         soll = ['12/11/2001 12:00:00', '01/03/2015 17:56:00',
                 '01/12/1990 00:00:00']
