@@ -40,6 +40,7 @@ python -m pytest --cov=pyjams --cov-report term-missing -v tests/test_datetime.p
 
 """
 import unittest
+import warnings
 
 
 def _flatten(itr):
@@ -60,13 +61,15 @@ class TestDatetime(unittest.TestCase):
     Tests for class_datetime.py
     """
     def setUp(self):
-        self._excelcalendars = ['excel', 'excel1900', 'excel1904']
-        self._decimalcalendars = ['decimal', 'decimal360', 'decimal365',
-                                  'decimal366']
-        self._noncfcalendars = self._excelcalendars + self._decimalcalendars
         self._cfcalendars = ['standard', 'gregorian', 'proleptic_gregorian',
                              'noleap', 'julian', 'all_leap', '365_day',
                              '366_day', '360_day']
+        self._excelcalendars = ['excel', 'excel1900', 'excel1904']
+        self._excelcfequivalents = ['julian', 'julian', 'julian']
+        self._decimalcalendars = ['decimal', 'decimal360', 'decimal365',
+                                  'decimal366']
+        self._decimalcfequivalents = ['proleptic_gregorian', '360_day',
+                                      '365_day', '366_day']
         self._dayspermonth      = [31, 28, 31, 30, 31, 30,
                                    31, 31, 30, 31, 30, 31]
         self._dayspermonth_leap = [31, 29, 31, 30, 31, 30,
@@ -117,11 +120,13 @@ class TestDatetime(unittest.TestCase):
         import datetime as dt
         from pyjams import datetime
 
-        # Back and forth for _noncfcalendars
+        # Back and forth for non-cfcalendars
 
         # precision problem for some calendars of _cfcalendars, i.e.
         #     'noleap', 'all_leap', '365_day', '366_day', '360_day'
-        calendars = self._noncfcalendars
+        # _noncfcalendars = self._decimalcalendars + self._excelcalendars
+        _noncfcalendars = self._decimalcalendars
+        calendars = _noncfcalendars
         # calendars = self._cfcalendars
         units = ['', 'day as %Y%m%d.%f', 'month as %Y%m.%f', 'year as %Y.%f']
         formats = ['%Y-%m-%d %H:%M:%S', '%d.%m.%Y %H:%M:%S',
@@ -139,18 +144,15 @@ class TestDatetime(unittest.TestCase):
         f2nums = [date2num, date2dec]
         for calendar in calendars:
             for unit in units:
-                for format in formats:
+                for iformat in formats:
                     for only_pyjams in only_pyjamss:
                         for only_cftime in only_cftimes:
                             for only_python in only_pythons:
                                 for has_year_zero in has_year_zeros:
                                     for itype in range(len(itypes)):
-                                        # print(calendar, unit, format,
-                                        #       only_cftime, only_python,
-                                        #       has_year_zero, itypes[itype])
                                         indates = itypes[itype](self.idates)
                                         jdates = date2date(indates,
-                                                           format=format)
+                                                           format=iformat)
                                         ihave0 = has_year_zero
                                         if ( has_year_zero and
                                              (calendar in self._excelcalendars) ):
@@ -160,7 +162,8 @@ class TestDatetime(unittest.TestCase):
                                             jdates, units=unit,
                                             calendar=calendar,
                                             has_year_zero=ihave0,
-                                            format=format)
+                                            format=iformat,
+                                            ensure_seconds=True)
                                         f2date = f2dates[random.randint(0, 1)]
                                         odates = f2date(
                                             idec, units=unit, calendar=calendar,
@@ -173,6 +176,25 @@ class TestDatetime(unittest.TestCase):
                                         assert isinstance(jdates, ttypes[itype])
                                         assert isinstance(idec, ttypes[itype])
                                         assert isinstance(odates, ttypes[itype])
+                                        # odates2 = f2date(
+                                        #     idec, units=unit, calendar=calendar,
+                                        #     only_use_pyjams_datetimes=only_pyjams,
+                                        #     only_use_cftime_datetimes=only_cftime,
+                                        #     only_use_python_datetimes=only_python,
+                                        #     has_year_zero=ihave0,
+                                        #     # format='%Y-%m-%d %H:%M:%S.%f',
+                                        #     format='.%f',
+                                        #     return_arrays=False)
+                                        # if np.any(
+                                        #         np.array(odates2) !=
+                                        #         np.str_('.000000')):
+                                        #     print('Microsecond0', calendar, unit,
+                                        #           iformat, only_pyjams,
+                                        #           only_cftime, only_python,
+                                        #           has_year_zero, itypes[itype],
+                                        #           np.array(_flatten(odates2)))
+                                        assert isinstance(jdates,
+                                                          ttypes[itype])
                                         self.assertEqual(_flatten(odates),
                                                          _flatten(indates))
 
@@ -198,15 +220,12 @@ class TestDatetime(unittest.TestCase):
         f2nums = [date2num, date2dec]
         for calendar in calendars:
             for unit in units:
-                for format in formats:
+                for iformat in formats:
                     for only_pyjams in only_pyjamss:
                         for only_cftime in only_cftimes:
                             for only_python in only_pythons:
                                 for has_year_zero in has_year_zeros:
                                     for itype in range(len(itypes)):
-                                        # print(calendar, unit, format,
-                                        #       only_cftime, only_python,
-                                        #       has_year_zero, itypes[itype])
                                         if calendar in ['',
                                                         'gregorian',
                                                         'standard']:
@@ -215,13 +234,14 @@ class TestDatetime(unittest.TestCase):
                                         else:
                                             indates = itypes[itype](self.idates)
                                         jdates = date2date(indates,
-                                                           format=format)
+                                                           format=iformat)
                                         f2num = f2nums[random.randint(0, 1)]
                                         idec = f2num(
                                             jdates, units=unit,
                                             calendar=calendar,
                                             has_year_zero=has_year_zero,
-                                            format=format)
+                                            format=iformat,
+                                            ensure_seconds=True)
                                         f2date = f2dates[random.randint(0, 1)]
                                         odates = f2date(
                                             idec, units=unit, calendar=calendar,
@@ -242,20 +262,20 @@ class TestDatetime(unittest.TestCase):
         calendar = ''
         units = ['', 'day as %Y%m%d.%f', 'month as %Y%m.%f', 'year as %Y.%f',
                  'days since 1900-01-01 00:00:00']
-        format = ''
+        iformat = ''
         itypes = [list, tuple, np.array]
         ttypes = [list, tuple, np.ndarray]
         f2dates = [num2date, dec2date]
         f2nums  = [date2num, date2dec]
         for unit in units:
             for itype in range(len(itypes)):
-                # print(unit, itypes[itype])
                 indates = itypes[itype](self.idates)
-                jdates = date2date(indates, format=format)
+                jdates = date2date(indates, format=iformat)
                 f2num = f2nums[random.randint(0, 1)]
                 idec = f2num(
                     jdates, units=unit, calendar=calendar,
-                    format=format)
+                    format=iformat,
+                    ensure_seconds=True)
                 f2date = f2dates[random.randint(0, 1)]
                 odates = f2date(
                     idec, units=unit, calendar=calendar,
@@ -278,11 +298,11 @@ class TestDatetime(unittest.TestCase):
         f2nums = [date2num, date2dec]
         for unit in units:
             for itype in range(len(itypes)):
-                # print(unit, itypes[itype])
                 indates = itypes[itype]([self.idates[0]])
                 jdates = date2date(indates)
                 f2num = f2nums[random.randint(0, 1)]
-                idec = f2num(jdates, units=unit, calendar=calendar)
+                idec = f2num(jdates, units=unit, calendar=calendar,
+                             ensure_seconds=True)
                 f2date = f2dates[random.randint(0, 1)]
                 odates = f2date(
                     idec, units=unit, calendar=calendar,
@@ -302,11 +322,11 @@ class TestDatetime(unittest.TestCase):
         f2dates = [num2date, dec2date]
         f2nums = [date2num, date2dec]
         for unit in units:
-            # print(unit)
             indates = self.idates[0]
             jdates = date2date(indates)
             f2num = f2nums[random.randint(0, 1)]
-            idec = f2num(jdates, units=unit, calendar=calendar)
+            idec = f2num(jdates, units=unit, calendar=calendar,
+                         ensure_seconds=True)
             f2date = f2dates[random.randint(0, 1)]
             odates = f2date(
                 idec, units=unit, calendar=calendar,
@@ -314,38 +334,37 @@ class TestDatetime(unittest.TestCase):
                 return_arrays=False)
             self.assertEqual(odates, indates)
 
-        # Back and forth with microseconds
+        # # Back and forth with microseconds
 
-        calendar = 'decimal'
-        units = ['', 'day as %Y%m%d.%f', 'month as %Y%m.%f', 'year as %Y.%f',
-                 'days since 1900-01-01 00:00:00']
-        units = ['month as %Y%m.%f']
-        itypes = [list, tuple, np.array]
-        ttypes = [list, tuple, np.ndarray]
-        f2dates = [num2date, dec2date]
-        f2nums = [date2num, date2dec]
-        iform = self.iformat + '.%f'
-        for unit in units:
-            for itype in range(len(itypes)):
-                # print(unit, itypes[itype])
-                indates = itypes[itype](self.idates)
-                jdates = date2date(indates, format='en')
-                jdates = itypes[itype]([
-                    jdates[i] + '.{:06d}'.format(self.microsecond[i])
-                    for i in range(len(jdates)) ])
-                f2num = f2nums[random.randint(0, 1)]
-                idec = f2num(jdates, units=unit, calendar=calendar,
-                             format=iform)
-                f2date = f2dates[random.randint(0, 1)]
-                odates = f2date(
-                    idec, units=unit, calendar=calendar,
-                    format=iform,
-                    return_arrays=False)
-                assert isinstance(jdates, ttypes[itype])
-                assert isinstance(idec, ttypes[itype])
-                assert isinstance(odates, ttypes[itype])
-                self.assertEqual(_flatten(odates),
-                                 _flatten(jdates))
+        # calendar = 'decimal'
+        # units = ['', 'day as %Y%m%d.%f', 'month as %Y%m.%f', 'year as %Y.%f',
+        #          'days since 1900-01-01 00:00:00']
+        # units = ['month as %Y%m.%f']
+        # itypes = [list, tuple, np.array]
+        # ttypes = [list, tuple, np.ndarray]
+        # f2dates = [num2date, dec2date]
+        # f2nums = [date2num, date2dec]
+        # iform = self.iformat + '.%f'
+        # for unit in units:
+        #     for itype in range(len(itypes)):
+        #         indates = itypes[itype](self.idates)
+        #         jdates = date2date(indates, format='en')
+        #         jdates = itypes[itype]([
+        #             jdates[i] + '.{:06d}'.format(self.microsecond[i])
+        #             for i in range(len(jdates)) ])
+        #         f2num = f2nums[random.randint(0, 1)]
+        #         idec = f2num(jdates, units=unit, calendar=calendar,
+        #                      format=iform)
+        #         f2date = f2dates[random.randint(0, 1)]
+        #         odates = f2date(
+        #             idec, units=unit, calendar=calendar,
+        #             format=iform,
+        #             return_arrays=False)
+        #         assert isinstance(jdates, ttypes[itype])
+        #         assert isinstance(idec, ttypes[itype])
+        #         assert isinstance(odates, ttypes[itype])
+        #         self.assertEqual(_flatten(odates),
+        #                          _flatten(jdates))
 
         # given calendar takes precedence on calendar of datetime objects
 
@@ -359,10 +378,9 @@ class TestDatetime(unittest.TestCase):
                             calendar='decimal')
                    for i in range(len(self.year)) ]
         rdates = [ dt.datetime(self.year[i], self.month[i], self.day[i],
-                            self.hour[i], self.minute[i], self.second[i])
+                               self.hour[i], self.minute[i], self.second[i])
                    for i in range(len(self.year)) ]
         for ical in calendar:
-            # print(ical)
             indates = date2num(self.idates, format=self.iformat, calendar=ical)
             odates = date2num(cdates, calendar=ical)
             self.assertEqual(odates, indates)
@@ -383,40 +401,39 @@ class TestDatetime(unittest.TestCase):
                             calendar='decimal')
                    for i in range(len(self.year)) ]
         rdates = [ dt.datetime(self.year[i], self.month[i], self.day[i],
-                            self.hour[i], self.minute[i], self.second[i])
+                               self.hour[i], self.minute[i], self.second[i])
                    for i in range(len(self.year)) ]
         for ical in calendar:
-            # print(ical)
             inyr, inmo, indy, inhr, inmi, insc, inms = (
                 date2num(self.idates, format=self.iformat, calendar=ical,
                          return_arrays=True))
             oyr, omo, ody, ohr, omi, osc, oms = (
                 date2num(cdates, calendar=ical, return_arrays=True))
-            self.assertEqual(oyr, inyr)
-            self.assertEqual(omo, inmo)
-            self.assertEqual(ody, indy)
-            self.assertEqual(ohr, inhr)
-            self.assertEqual(omi, inmi)
-            self.assertEqual(osc, insc)
             self.assertEqual(oms, inms)
+            self.assertEqual(osc, insc)
+            self.assertEqual(omi, inmi)
+            self.assertEqual(ohr, inhr)
+            self.assertEqual(oyr, inyr)
+            self.assertEqual(ody, indy)
+            self.assertEqual(omo, inmo)
             oyr, omo, ody, ohr, omi, osc, oms = (
                 date2num(ddates, calendar=ical, return_arrays=True))
-            self.assertEqual(oyr, inyr)
-            self.assertEqual(omo, inmo)
-            self.assertEqual(ody, indy)
-            self.assertEqual(ohr, inhr)
-            self.assertEqual(omi, inmi)
-            self.assertEqual(osc, insc)
             self.assertEqual(oms, inms)
+            self.assertEqual(osc, insc)
+            self.assertEqual(omi, inmi)
+            self.assertEqual(ohr, inhr)
+            self.assertEqual(ody, indy)
+            self.assertEqual(omo, inmo)
+            self.assertEqual(oyr, inyr)
             oyr, omo, ody, ohr, omi, osc, oms = (
                 date2num(rdates, calendar=ical, return_arrays=True))
-            self.assertEqual(oyr, inyr)
-            self.assertEqual(omo, inmo)
-            self.assertEqual(ody, indy)
-            self.assertEqual(ohr, inhr)
-            self.assertEqual(omi, inmi)
-            self.assertEqual(osc, insc)
             self.assertEqual(oms, inms)
+            self.assertEqual(osc, insc)
+            self.assertEqual(omi, inmi)
+            self.assertEqual(ohr, inhr)
+            self.assertEqual(ody, indy)
+            self.assertEqual(omo, inmo)
+            self.assertEqual(oyr, inyr)
 
         # errors
 
@@ -461,15 +478,15 @@ class TestDatetime(unittest.TestCase):
 
         # Test methods of datetime class, years > 0
 
-        calendars = self._noncfcalendars
+        # _noncfcalendars = self._decimalcalendars + self._excelcalendars
+        # _cfequivalents = self._decimalcfequivalents + self._excelcfequivalents
+        _noncfcalendars = self._decimalcalendars
+        _cfequivalents = self._decimalcfequivalents
+        calendars = _noncfcalendars
         has_year_zeros = [None, True, False]
-        cfequivalents = ['julian', 'julian', 'julian',
-                         'proleptic_gregorian', '360_day',
-                         '365_day', '366_day']
-        cfcalendars = dict(zip(self._noncfcalendars, cfequivalents))
+        cfcalendars = dict(zip(_noncfcalendars, _cfequivalents))
         for calendar in calendars:
             for has_year_zero in has_year_zeros:
-                # print(calendar, has_year_zero)
                 ihave0 = has_year_zero
                 if calendar in self._excelcalendars:
                     ihave0 = False
@@ -488,10 +505,12 @@ class TestDatetime(unittest.TestCase):
                 # change_calendar - NotImplemented
 
                 # use cftime as reference
-                cdt = [ cf.datetime(*dt.to_tuple(),
-                                    calendar=cfcalendars[calendar],
-                                    has_year_zero=ihave0)
-                        for dt in idt ]
+                with warnings.catch_warnings():
+                    warnings.simplefilter("ignore")
+                    cdt = [ cf.datetime(*dt.to_tuple(),
+                                        calendar=cfcalendars[calendar],
+                                        has_year_zero=ihave0)
+                            for dt in idt ]
 
                 # dayofwk, dayofyr
                 ist  = [ dt.dayofyr() for dt in idt ]
@@ -509,7 +528,7 @@ class TestDatetime(unittest.TestCase):
                 mlen = [ _month_lengths(yy, calendar,
                                         has_year_zero=ihave0)
                          for yy in self.year ]
-                soll = [ mlen[mm][self.month[mm]-1]
+                soll = [ mlen[mm][self.month[mm] - 1]
                          for mm in range(len(self.month)) ]
                 self.assertEqual(_flatten(ist), _flatten(soll))
 
@@ -542,10 +561,10 @@ class TestDatetime(unittest.TestCase):
                 soll = self.idates
                 self.assertEqual(_flatten(ist), _flatten(soll))
                 ist  = [ dt.isoformat(' ', 'milliseconds') for dt in idt ]
-                soll = [ dd+'.000' for dd in self.idates ]
+                soll = [ dd + '.000' for dd in self.idates ]
                 self.assertEqual(_flatten(ist), _flatten(soll))
                 ist  = [ dt.isoformat(' ', 'microseconds') for dt in idt ]
-                soll = [ dd+'.000000' for dd in self.idates ]
+                soll = [ dd + '.000000' for dd in self.idates ]
                 self.assertEqual(_flatten(ist), _flatten(soll))
 
                 # replace
@@ -553,12 +572,12 @@ class TestDatetime(unittest.TestCase):
                 odt = list()
                 for i in range(len(self.year)):
                     kwarg = {
-                        'year': self.year[-(i+1)],
-                        'month': self.month[-(i+1)],
-                        'day': self.day[-(i+1)],
-                        'hour': self.hour[-(i+1)],
-                        'minute': self.minute[-(i+1)],
-                        'second': self.second[-(i+1)],
+                        'year': self.year[-(i + 1)],
+                        'month': self.month[-(i + 1)],
+                        'day': self.day[-(i + 1)],
+                        'hour': self.hour[-(i + 1)],
+                        'minute': self.minute[-(i + 1)],
+                        'second': self.second[-(i + 1)],
                         'has_year_zero': False
                     }
                     odt.append(idt[i].replace(**kwarg))
@@ -569,14 +588,14 @@ class TestDatetime(unittest.TestCase):
                 ohour   = iarrays[:, 3]
                 ominute = iarrays[:, 4]
                 osecond = iarrays[:, 5]
-                self.assertEqual(_flatten(oyear), _flatten(self.year[::-1]))
-                self.assertEqual(_flatten(omonth), _flatten(self.month[::-1]))
-                self.assertEqual(_flatten(oday), _flatten(self.day[::-1]))
-                self.assertEqual(_flatten(ohour), _flatten(self.hour[::-1]))
-                self.assertEqual(_flatten(ominute),
-                                 _flatten(self.minute[::-1]))
                 self.assertEqual(_flatten(osecond),
                                  _flatten(self.second[::-1]))
+                self.assertEqual(_flatten(ominute),
+                                 _flatten(self.minute[::-1]))
+                self.assertEqual(_flatten(ohour), _flatten(self.hour[::-1]))
+                self.assertEqual(_flatten(oday), _flatten(self.day[::-1]))
+                self.assertEqual(_flatten(omonth), _flatten(self.month[::-1]))
+                self.assertEqual(_flatten(oyear), _flatten(self.year[::-1]))
                 ist = [ dt.has_year_zero for dt in odt ]
                 soll = [ False for dt in odt ]
                 self.assertEqual(ist, soll)
@@ -635,25 +654,30 @@ class TestDatetime(unittest.TestCase):
                 ohour   = iarrays[:, 3]
                 ominute = iarrays[:, 4]
                 osecond = iarrays[:, 5]
-                self.assertEqual(_flatten(oyear), _flatten(self.year))
-                self.assertEqual(_flatten(omonth), _flatten(self.month))
-                self.assertEqual(_flatten(oday), _flatten(self.day))
-                self.assertEqual(_flatten(ohour), _flatten(self.hour))
-                self.assertEqual(_flatten(ominute), _flatten(self.minute))
+                # omsecond = iarrays[:, 6]
                 self.assertEqual(_flatten(osecond), _flatten(self.second))
+                self.assertEqual(_flatten(ominute), _flatten(self.minute))
+                self.assertEqual(_flatten(ohour), _flatten(self.hour))
+                self.assertEqual(_flatten(oday), _flatten(self.day))
+                self.assertEqual(_flatten(omonth), _flatten(self.month))
+                self.assertEqual(_flatten(oyear), _flatten(self.year))
                 # using return_arrays
                 idec = date2num(idt, units='', calendar=calendar,
-                                has_year_zero=ihave0)
+                                has_year_zero=ihave0,
+                                ensure_seconds=True)
                 oyear, omonth, oday, ohour, ominute, osecond, omsecond = (
                     num2date(idec, units='', calendar=calendar,
                              has_year_zero=ihave0,
                              return_arrays=True))
-                self.assertEqual(_flatten(oyear), _flatten(self.year))
-                self.assertEqual(_flatten(omonth), _flatten(self.month))
-                self.assertEqual(_flatten(oday), _flatten(self.day))
-                self.assertEqual(_flatten(ohour), _flatten(self.hour))
-                self.assertEqual(_flatten(ominute), _flatten(self.minute))
+                omsecond1 = np.array(_flatten(omsecond))
+                # if np.any(omsecond1 != 0.):
+                #     print('Second0', calendar, has_year_zero, omsecond1)
                 self.assertEqual(_flatten(osecond), _flatten(self.second))
+                self.assertEqual(_flatten(ominute), _flatten(self.minute))
+                self.assertEqual(_flatten(ohour), _flatten(self.hour))
+                self.assertEqual(_flatten(oday), _flatten(self.day))
+                self.assertEqual(_flatten(omonth), _flatten(self.month))
+                self.assertEqual(_flatten(oyear), _flatten(self.year))
 
                 # _add_timedelta - with __add__
 
@@ -850,7 +874,6 @@ class TestDatetime(unittest.TestCase):
         cfcalendars = dict(zip(self._decimalcalendars, cfequivalents))
         for calendar in calendars:
             for has_year_zero in has_year_zeros:
-                # print(calendar, has_year_zero)
                 ihave0 = has_year_zero
                 if cfcalendars[calendar] == 'proleptic_gregorian':
                     ihave0 = False
@@ -882,15 +905,17 @@ class TestDatetime(unittest.TestCase):
                                    isecond[i], imicrosecond[i],
                                    calendar=calendar,
                                    has_year_zero=ihave0)
-                         for i in range(len(iyear)) ]
+                          for i in range(len(iyear)) ]
 
                 # change_calendar - NotImplemented
 
                 # use cftime as reference
-                cdt = [ cf.datetime(*dt.to_tuple(),
-                                    calendar=cfcalendars[calendar],
-                                    has_year_zero=ihave0)
-                        for dt in idt ]
+                with warnings.catch_warnings():
+                    warnings.simplefilter("ignore")
+                    cdt = [ cf.datetime(*dt.to_tuple(),
+                                        calendar=cfcalendars[calendar],
+                                        has_year_zero=ihave0)
+                            for dt in idt ]
 
                 # dayofwk, dayofyr
                 ist  = [ dt.dayofyr() for dt in idt ]
@@ -908,7 +933,7 @@ class TestDatetime(unittest.TestCase):
                 mlen = [ _month_lengths(yy, calendar,
                                         has_year_zero=ihave0)
                          for yy in iyear ]
-                soll = [ mlen[mm][imonth[mm]-1]
+                soll = [ mlen[mm][imonth[mm] - 1]
                          for mm in range(len(imonth)) ]
                 self.assertEqual(_flatten(ist), _flatten(soll))
 
@@ -938,10 +963,10 @@ class TestDatetime(unittest.TestCase):
                 soll = idates
                 self.assertEqual(_flatten(ist), _flatten(soll))
                 ist  = [ dt.isoformat(' ', 'milliseconds') for dt in idt ]
-                soll = [ dd+'.000' for dd in idates ]
+                soll = [ dd + '.000' for dd in idates ]
                 self.assertEqual(_flatten(ist), _flatten(soll))
                 ist  = [ dt.isoformat(' ', 'microseconds') for dt in idt ]
-                soll = [ dd+'.000000' for dd in idates ]
+                soll = [ dd + '.000000' for dd in idates ]
                 self.assertEqual(_flatten(ist), _flatten(soll))
 
                 # replace
@@ -951,12 +976,12 @@ class TestDatetime(unittest.TestCase):
                     if ihave0 or (ihave0 is None):
                         ihave = False
                     kwarg = {
-                        'year': np.clip(iyear[-(i+1)], -9999, -1),
-                        'month': imonth[-(i+1)],
-                        'day': iday[-(i+1)],
-                        'hour': ihour[-(i+1)],
-                        'minute': iminute[-(i+1)],
-                        'second': isecond[-(i+1)],
+                        'year': np.clip(iyear[-(i + 1)], -9999, -1),
+                        'month': imonth[-(i + 1)],
+                        'day': iday[-(i + 1)],
+                        'hour': ihour[-(i + 1)],
+                        'minute': iminute[-(i + 1)],
+                        'second': isecond[-(i + 1)],
                         'has_year_zero': False
                     }
                     odt.append(idt[i].replace(**kwarg))
@@ -967,15 +992,15 @@ class TestDatetime(unittest.TestCase):
                 ohour   = iarrays[:, 3]
                 ominute = iarrays[:, 4]
                 osecond = iarrays[:, 5]
-                self.assertEqual(_flatten(oyear),
-                                 _flatten(np.clip(iyear[::-1], -9999, -1)))
-                self.assertEqual(_flatten(omonth), _flatten(imonth[::-1]))
-                self.assertEqual(_flatten(oday), _flatten(iday[::-1]))
-                self.assertEqual(_flatten(ohour), _flatten(ihour[::-1]))
-                self.assertEqual(_flatten(ominute),
-                                 _flatten(iminute[::-1]))
                 self.assertEqual(_flatten(osecond),
                                  _flatten(isecond[::-1]))
+                self.assertEqual(_flatten(ominute),
+                                 _flatten(iminute[::-1]))
+                self.assertEqual(_flatten(ohour), _flatten(ihour[::-1]))
+                self.assertEqual(_flatten(oday), _flatten(iday[::-1]))
+                self.assertEqual(_flatten(omonth), _flatten(imonth[::-1]))
+                self.assertEqual(_flatten(oyear),
+                                 _flatten(np.clip(iyear[::-1], -9999, -1)))
                 ist = [ dt.has_year_zero for dt in odt ]
                 soll = [ False for dt in odt ]
                 self.assertEqual(ist, soll)
@@ -1034,38 +1059,40 @@ class TestDatetime(unittest.TestCase):
                 ohour   = iarrays[:, 3]
                 ominute = iarrays[:, 4]
                 osecond = iarrays[:, 5]
-                self.assertEqual(_flatten(oyear), _flatten(iyear))
-                self.assertEqual(_flatten(omonth), _flatten(imonth))
-                self.assertEqual(_flatten(oday), _flatten(iday))
-                self.assertEqual(_flatten(ohour), _flatten(ihour))
-                self.assertEqual(_flatten(ominute), _flatten(iminute))
                 self.assertEqual(_flatten(osecond), _flatten(isecond))
+                self.assertEqual(_flatten(ominute), _flatten(iminute))
+                self.assertEqual(_flatten(ohour), _flatten(ihour))
+                self.assertEqual(_flatten(oday), _flatten(iday))
+                self.assertEqual(_flatten(omonth), _flatten(imonth))
+                self.assertEqual(_flatten(oyear), _flatten(iyear))
                 # using return_arrays
                 idec = date2num(idt, units='', calendar=calendar,
-                                has_year_zero=ihave0)
+                                has_year_zero=ihave0,
+                                ensure_seconds=True)
                 oyear, omonth, oday, ohour, ominute, osecond, omsecond = (
                     num2date(idec, units='', calendar=calendar,
                              has_year_zero=ihave0,
                              return_arrays=True))
-                self.assertEqual(_flatten(oyear), _flatten(iyear))
-                self.assertEqual(_flatten(omonth), _flatten(imonth))
-                self.assertEqual(_flatten(oday), _flatten(iday))
-                self.assertEqual(_flatten(ohour), _flatten(ihour))
-                self.assertEqual(_flatten(ominute), _flatten(iminute))
                 self.assertEqual(_flatten(osecond), _flatten(isecond))
+                self.assertEqual(_flatten(ominute), _flatten(iminute))
+                self.assertEqual(_flatten(ohour), _flatten(ihour))
+                self.assertEqual(_flatten(oday), _flatten(iday))
+                self.assertEqual(_flatten(omonth), _flatten(imonth))
+                self.assertEqual(_flatten(oyear), _flatten(iyear))
                 # using return_arrays with absolute days
                 idec = date2num(idt, units='day as %Y%m%d.%f',
-                                calendar=calendar, has_year_zero=ihave0)
+                                calendar=calendar, has_year_zero=ihave0,
+                                ensure_seconds=True)
                 oyear, omonth, oday, ohour, ominute, osecond, omsecond = (
                     num2date(idec, units='day as %Y%m%d.%f', calendar=calendar,
                              has_year_zero=ihave0,
                              return_arrays=True))
-                self.assertEqual(_flatten(oyear), _flatten(iyear))
-                self.assertEqual(_flatten(omonth), _flatten(imonth))
-                self.assertEqual(_flatten(oday), _flatten(iday))
-                self.assertEqual(_flatten(ohour), _flatten(ihour))
-                self.assertEqual(_flatten(ominute), _flatten(iminute))
                 self.assertEqual(_flatten(osecond), _flatten(isecond))
+                self.assertEqual(_flatten(ominute), _flatten(iminute))
+                self.assertEqual(_flatten(ohour), _flatten(ihour))
+                self.assertEqual(_flatten(oday), _flatten(iday))
+                self.assertEqual(_flatten(omonth), _flatten(imonth))
+                self.assertEqual(_flatten(oyear), _flatten(iyear))
 
                 # _add_timedelta - with __add__
 
@@ -1215,10 +1242,19 @@ class TestDatetime(unittest.TestCase):
             assert dt.calendar == 'decimal'
 
         # issue #187 of cftime: roundtrip near second boundary
+        # round_microseconds()
         dt1 = datetime(1810, 4, 24, 16, 15, 10)
         units = 'days since -4713-01-01 12:00'
         dt2 = num2date(date2num(dt1, units, calendar='decimal'),
+                       units, calendar='decimal').round_microseconds()
+        assert dt1 == dt2
+        # set microsecond to 0
+        dt1 = datetime(1810, 4, 24, 16, 15, 10)
+        units = 'days since -4713-01-01 12:00'
+        dt2 = num2date(date2num(dt1, units, calendar='decimal',
+                                ensure_seconds=True),
                        units, calendar='decimal')
+        dt2.microsecond = 0
         assert dt1 == dt2
 
         # errors
